@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -55,15 +55,13 @@
 static Uint8 snd2au(int sample);
 
 /* Audio driver bootstrap functions */
-static void
-SUNAUDIO_DetectDevices(void)
+static void SUNAUDIO_DetectDevices(void)
 {
     SDL_EnumUnixAudioDevices(1, (int (*)(int)) NULL);
 }
 
 #ifdef DEBUG_AUDIO
-void
-CheckUnderflow(_THIS)
+void CheckUnderflow(_THIS)
 {
 #ifdef AUDIO_GETBUFINFO
     audio_info_t info;
@@ -78,8 +76,7 @@ CheckUnderflow(_THIS)
 }
 #endif
 
-static void
-SUNAUDIO_WaitDevice(_THIS)
+static void SUNAUDIO_WaitDevice(_THIS)
 {
 #ifdef AUDIO_GETBUFINFO
 #define SLEEP_FUDGE 10      /* 10 ms scheduling fudge factor */
@@ -102,8 +99,7 @@ SUNAUDIO_WaitDevice(_THIS)
 #endif
 }
 
-static void
-SUNAUDIO_PlayDevice(_THIS)
+static void SUNAUDIO_PlayDevice(_THIS)
 {
     /* Write the audio data */
     if (this->hidden->ulaw_only) {
@@ -170,14 +166,12 @@ SUNAUDIO_PlayDevice(_THIS)
     }
 }
 
-static Uint8 *
-SUNAUDIO_GetDeviceBuf(_THIS)
+static Uint8 *SUNAUDIO_GetDeviceBuf(_THIS)
 {
     return (this->hidden->mixbuf);
 }
 
-static void
-SUNAUDIO_CloseDevice(_THIS)
+static void SUNAUDIO_CloseDevice(_THIS)
 {
     SDL_free(this->hidden->ulaw_buf);
     if (this->hidden->audio_fd >= 0) {
@@ -187,8 +181,7 @@ SUNAUDIO_CloseDevice(_THIS)
     SDL_free(this->hidden);
 }
 
-static int
-SUNAUDIO_OpenDevice(_THIS, const char *devname)
+static int SUNAUDIO_OpenDevice(_THIS, const char *devname)
 {
 #ifdef AUDIO_SETINFO
     int enc;
@@ -209,8 +202,7 @@ SUNAUDIO_OpenDevice(_THIS, const char *devname)
     }
 
     /* Initialize all variables that we clean on shutdown */
-    this->hidden = (struct SDL_PrivateAudioData *)
-        SDL_malloc((sizeof *this->hidden));
+    this->hidden = (struct SDL_PrivateAudioData *)SDL_malloc(sizeof(*this->hidden));
     if (this->hidden == NULL) {
         return SDL_OutOfMemory();
     }
@@ -360,8 +352,7 @@ SUNAUDIO_OpenDevice(_THIS, const char *devname)
 /*      provided "as is" without express or implied warranty.           */
 /************************************************************************/
 
-static Uint8
-snd2au(int sample)
+static Uint8 snd2au(int sample)
 {
 
     int mask;
@@ -395,8 +386,7 @@ snd2au(int sample)
     return (mask & sample);
 }
 
-static SDL_bool
-SUNAUDIO_Init(SDL_AudioDriverImpl * impl)
+static SDL_bool SUNAUDIO_Init(SDL_AudioDriverImpl * impl)
 {
     /* Set the function pointers */
     impl->DetectDevices = SUNAUDIO_DetectDevices;
