@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -27,6 +27,7 @@
 
 #if SDL_HAPTIC_DINPUT
 
+#include "SDL_hints.h"
 #include "SDL_stdinc.h"
 #include "SDL_timer.h"
 #include "SDL_windowshaptic_c.h"
@@ -36,8 +37,11 @@
 /*
  * External stuff.
  */
+#ifdef SDL_VIDEO_DRIVER_WINDOWS
 extern HWND SDL_HelperWindow;
-
+#else
+static const HWND SDL_HelperWindow = NULL;
+#endif
 
 /*
  * Internal stuff.
@@ -45,12 +49,10 @@ extern HWND SDL_HelperWindow;
 static SDL_bool coinitialized = SDL_FALSE;
 static LPDIRECTINPUT8 dinput = NULL;
 
-
 /*
  * Like SDL_SetError but for DX error codes.
  */
-static int
-DI_SetError(const char *str, HRESULT err)
+static int DI_SetError(const char *str, HRESULT err)
 {
     return SDL_SetError("Haptic error %s", str);
 }
@@ -58,25 +60,28 @@ DI_SetError(const char *str, HRESULT err)
 /*
  * Callback to find the haptic devices.
  */
-static BOOL CALLBACK
-EnumHapticsCallback(const DIDEVICEINSTANCE * pdidInstance, VOID * pContext)
+static BOOL CALLBACK EnumHapticsCallback(const DIDEVICEINSTANCE *pdidInstance, VOID *pContext)
 {
-    (void) pContext;
+    (void)pContext;
     SDL_DINPUT_HapticMaybeAddDevice(pdidInstance);
-    return DIENUM_CONTINUE;  /* continue enumerating */
+    return DIENUM_CONTINUE; /* continue enumerating */
 }
 
-int
-SDL_DINPUT_HapticInit(void)
+int SDL_DINPUT_HapticInit(void)
 {
     HRESULT ret;
     HINSTANCE instance;
     DWORD devClass;
 
-    if (dinput != NULL) {       /* Already open. */
+    if (dinput != NULL) { /* Already open. */
         return SDL_SetError("Haptic: SubSystem already open.");
     }
 
+    if (!SDL_GetHintBoolean(SDL_HINT_DIRECTINPUT_ENABLED, SDL_TRUE)) {
+        /* In some environments, IDirectInput8_Initialize / _EnumDevices can take a minute even with no controllers. */
+        return 0;
+    }
+
     ret = WIN_CoInitialize();
     if (FAILED(ret)) {
         return DI_SetError("Coinitialize", ret);
@@ -85,7 +90,7 @@ SDL_DINPUT_HapticInit(void)
     coinitialized = SDL_TRUE;
 
     ret = CoCreateInstance(&CLSID_DirectInput8, NULL, CLSCTX_INPROC_SERVER,
-        &IID_IDirectInput8, (LPVOID *) &dinput);
+                           &IID_IDirectInput8, (LPVOID *)&dinput);
     if (FAILED(ret)) {
         SDL_SYS_HapticQuit();
         return DI_SetError("CoCreateInstance", ret);
@@ -96,7 +101,7 @@ SDL_DINPUT_HapticInit(void)
     if (instance == NULL) {
         SDL_SYS_HapticQuit();
         return SDL_SetError("GetModuleHandle() failed with error code %lu.",
-            GetLastError());
+                            GetLastError());
     }
     ret = IDirectInput8_Initialize(dinput, instance, DIRECTINPUT_VERSION);
     if (FAILED(ret)) {
@@ -116,7 +121,7 @@ SDL_DINPUT_HapticInit(void)
                                         EnumHapticsCallback,
                                         NULL,
                                         DIEDFL_FORCEFEEDBACK |
-                                        DIEDFL_ATTACHEDONLY);
+                                            DIEDFL_ATTACHEDONLY);
         if (FAILED(ret)) {
             SDL_SYS_HapticQuit();
             return DI_SetError("Enumerating DirectInput devices", ret);
@@ -126,8 +131,7 @@ SDL_DINPUT_HapticInit(void)
     return 0;
 }
 
-int
-SDL_DINPUT_HapticMaybeAddDevice(const DIDEVICEINSTANCE * pdidInstance)
+int SDL_DINPUT_HapticMaybeAddDevice(const DIDEVICEINSTANCE *pdidInstance)
 {
     HRESULT ret;
     LPDIRECTINPUTDEVICE8 device;
@@ -136,13 +140,13 @@ SDL_DINPUT_HapticMaybeAddDevice(const DIDEVICEINSTANCE * pdidInstance)
     SDL_hapticlist_item *item = NULL;
 
     if (dinput == NULL) {
-        return -1;  /* not initialized. We'll pick these up on enumeration if we init later. */
+        return -1; /* not initialized. We'll pick these up on enumeration if we init later. */
     }
 
     /* Make sure we don't already have it */
     for (item = SDL_hapticlist; item; item = item->next) {
         if ((!item->bXInputHaptic) && (SDL_memcmp(&item->instance, pdidInstance, sizeof(*pdidInstance)) == 0)) {
-            return -1;  /* Already added */
+            return -1; /* Already added */
         }
     }
 
@@ -164,7 +168,7 @@ SDL_DINPUT_HapticMaybeAddDevice(const DIDEVICEINSTANCE * pdidInstance)
     }
 
     if ((capabilities.dwFlags & needflags) != needflags) {
-        return -1;  /* not a device we can use. */
+        return -1; /* not a device we can use. */
     }
 
     item = (SDL_hapticlist_item *)SDL_calloc(1, sizeof(SDL_hapticlist_item));
@@ -185,14 +189,13 @@ SDL_DINPUT_HapticMaybeAddDevice(const DIDEVICEINSTANCE * pdidInstance)
     return SDL_SYS_AddHapticDevice(item);
 }
 
-int
-SDL_DINPUT_HapticMaybeRemoveDevice(const DIDEVICEINSTANCE * pdidInstance)
+int SDL_DINPUT_HapticMaybeRemoveDevice(const DIDEVICEINSTANCE *pdidInstance)
 {
     SDL_hapticlist_item *item;
     SDL_hapticlist_item *prev = NULL;
 
     if (dinput == NULL) {
-        return -1;  /* not initialized, ignore this. */
+        return -1; /* not initialized, ignore this. */
     }
 
     for (item = SDL_hapticlist; item != NULL; item = item->next) {
@@ -208,10 +211,9 @@ SDL_DINPUT_HapticMaybeRemoveDevice(const DIDEVICEINSTANCE * pdidInstance)
 /*
  * Callback to get supported axes.
  */
-static BOOL CALLBACK
-DI_DeviceObjectCallback(LPCDIDEVICEOBJECTINSTANCE dev, LPVOID pvRef)
+static BOOL CALLBACK DI_DeviceObjectCallback(LPCDIDEVICEOBJECTINSTANCE dev, LPVOID pvRef)
 {
-    SDL_Haptic *haptic = (SDL_Haptic *) pvRef;
+    SDL_Haptic *haptic = (SDL_Haptic *)pvRef;
 
     if ((dev->dwType & DIDFT_AXIS) && (dev->dwFlags & DIDOI_FFACTUATOR)) {
         const GUID *guid = &dev->guidType;
@@ -229,7 +231,7 @@ DI_DeviceObjectCallback(LPCDIDEVICEOBJECTINSTANCE dev, LPVOID pvRef)
         } else if (WIN_IsEqualGUID(guid, &GUID_RzAxis)) {
             offset = DIJOFS_RZ;
         } else {
-            return DIENUM_CONTINUE;   /* can't use this, go on. */
+            return DIENUM_CONTINUE; /* can't use this, go on. */
         }
 
         haptic->hwdata->axes[haptic->naxes] = offset;
@@ -247,14 +249,13 @@ DI_DeviceObjectCallback(LPCDIDEVICEOBJECTINSTANCE dev, LPVOID pvRef)
 /*
  * Callback to get all supported effects.
  */
-#define EFFECT_TEST(e,s)               \
-if (WIN_IsEqualGUID(&pei->guid, &(e)))   \
-   haptic->supported |= (s)
-static BOOL CALLBACK
-DI_EffectCallback(LPCDIEFFECTINFO pei, LPVOID pv)
+#define EFFECT_TEST(e, s)                  \
+    if (WIN_IsEqualGUID(&pei->guid, &(e))) \
+    haptic->supported |= (s)
+static BOOL CALLBACK DI_EffectCallback(LPCDIEFFECTINFO pei, LPVOID pv)
 {
     /* Prepare the haptic device. */
-    SDL_Haptic *haptic = (SDL_Haptic *) pv;
+    SDL_Haptic *haptic = (SDL_Haptic *)pv;
 
     /* Get supported. */
     EFFECT_TEST(GUID_Spring, SDL_HAPTIC_SPRING);
@@ -285,8 +286,7 @@ DI_EffectCallback(LPCDIEFFECTINFO pei, LPVOID pv)
  *       - Reset actuators.
  *       - Get supported features.
  */
-static int
-SDL_DINPUT_HapticOpenFromDevice(SDL_Haptic * haptic, LPDIRECTINPUTDEVICE8 device8, SDL_bool is_joystick)
+static int SDL_DINPUT_HapticOpenFromDevice(SDL_Haptic *haptic, LPDIRECTINPUTDEVICE8 device8, SDL_bool is_joystick)
 {
     HRESULT ret;
     DIPROPDWORD dipdw;
@@ -309,12 +309,12 @@ SDL_DINPUT_HapticOpenFromDevice(SDL_Haptic * haptic, LPDIRECTINPUTDEVICE8 device
        !!! FIXME:  to work, and that's probably the common case. Still,
        !!! FIXME:  ideally, We need to unify the opening code. */
 
-    if (!is_joystick) {  /* if is_joystick, we already set this up elsewhere. */
+    if (!is_joystick) { /* if is_joystick, we already set this up elsewhere. */
         /* Grab it exclusively to use force feedback stuff. */
         ret = IDirectInputDevice8_SetCooperativeLevel(haptic->hwdata->device,
                                                       SDL_HelperWindow,
                                                       DISCL_EXCLUSIVE |
-                                                      DISCL_BACKGROUND);
+                                                          DISCL_BACKGROUND);
         if (FAILED(ret)) {
             DI_SetError("Setting cooperative level to exclusive", ret);
             goto acquire_err;
@@ -328,7 +328,6 @@ SDL_DINPUT_HapticOpenFromDevice(SDL_Haptic * haptic, LPDIRECTINPUTDEVICE8 device
             goto acquire_err;
         }
 
-
         /* Acquire the device. */
         ret = IDirectInputDevice8_Acquire(haptic->hwdata->device);
         if (FAILED(ret)) {
@@ -370,7 +369,7 @@ SDL_DINPUT_HapticOpenFromDevice(SDL_Haptic * haptic, LPDIRECTINPUTDEVICE8 device
         DI_SetError("Enumerating supported effects", ret);
         goto acquire_err;
     }
-    if (haptic->supported == 0) {       /* Error since device supports nothing. */
+    if (haptic->supported == 0) { /* Error since device supports nothing. */
         SDL_SetError("Haptic: Internal error on finding supported effects.");
         goto acquire_err;
     }
@@ -383,7 +382,7 @@ SDL_DINPUT_HapticOpenFromDevice(SDL_Haptic * haptic, LPDIRECTINPUTDEVICE8 device
     dipdw.dwData = 10000;
     ret = IDirectInputDevice8_SetProperty(haptic->hwdata->device,
                                           DIPROP_FFGAIN, &dipdw.diph);
-    if (!FAILED(ret)) {         /* Gain is supported. */
+    if (!FAILED(ret)) { /* Gain is supported. */
         haptic->supported |= SDL_HAPTIC_GAIN;
     }
     dipdw.diph.dwObj = 0;
@@ -391,7 +390,7 @@ SDL_DINPUT_HapticOpenFromDevice(SDL_Haptic * haptic, LPDIRECTINPUTDEVICE8 device
     dipdw.dwData = DIPROPAUTOCENTER_OFF;
     ret = IDirectInputDevice8_SetProperty(haptic->hwdata->device,
                                           DIPROP_AUTOCENTER, &dipdw.diph);
-    if (!FAILED(ret)) {         /* Autocenter is supported. */
+    if (!FAILED(ret)) { /* Autocenter is supported. */
         haptic->supported |= SDL_HAPTIC_AUTOCENTER;
     }
 
@@ -399,11 +398,11 @@ SDL_DINPUT_HapticOpenFromDevice(SDL_Haptic * haptic, LPDIRECTINPUTDEVICE8 device
     haptic->supported |= SDL_HAPTIC_STATUS | SDL_HAPTIC_PAUSE;
 
     /* Check maximum effects. */
-    haptic->neffects = 128;     /* This is not actually supported as thus under windows,
-                                   there is no way to tell the number of EFFECTS that a
-                                   device can hold, so we'll just use a "random" number
-                                   instead and put warnings in SDL_haptic.h */
-    haptic->nplaying = 128;     /* Even more impossible to get this then neffects. */
+    haptic->neffects = 128; /* This is not actually supported as thus under windows,
+                               there is no way to tell the number of EFFECTS that a
+                               device can hold, so we'll just use a "random" number
+                               instead and put warnings in SDL_haptic.h */
+    haptic->nplaying = 128; /* Even more impossible to get this then neffects. */
 
     /* Prepare effects memory. */
     haptic->effects = (struct haptic_effect *)
@@ -419,20 +418,19 @@ SDL_DINPUT_HapticOpenFromDevice(SDL_Haptic * haptic, LPDIRECTINPUTDEVICE8 device
     return 0;
 
     /* Error handling */
-  acquire_err:
+acquire_err:
     IDirectInputDevice8_Unacquire(haptic->hwdata->device);
     return -1;
 }
 
-int
-SDL_DINPUT_HapticOpen(SDL_Haptic * haptic, SDL_hapticlist_item *item)
+int SDL_DINPUT_HapticOpen(SDL_Haptic *haptic, SDL_hapticlist_item *item)
 {
     HRESULT ret;
     LPDIRECTINPUTDEVICE8 device;
 
     /* Open the device */
     ret = IDirectInput8_CreateDevice(dinput, &item->instance.guidInstance,
-        &device, NULL);
+                                     &device, NULL);
     if (FAILED(ret)) {
         DI_SetError("Creating DirectInput device", ret);
         return -1;
@@ -445,8 +443,7 @@ SDL_DINPUT_HapticOpen(SDL_Haptic * haptic, SDL_hapticlist_item *item)
     return 0;
 }
 
-int
-SDL_DINPUT_JoystickSameHaptic(SDL_Haptic * haptic, SDL_Joystick * joystick)
+int SDL_DINPUT_JoystickSameHaptic(SDL_Haptic *haptic, SDL_Joystick *joystick)
 {
     HRESULT ret;
     DIDEVICEINSTANCE hap_instance, joy_instance;
@@ -456,12 +453,12 @@ SDL_DINPUT_JoystickSameHaptic(SDL_Haptic * haptic, SDL_Joystick * joystick)
 
     /* Get the device instances. */
     ret = IDirectInputDevice8_GetDeviceInfo(haptic->hwdata->device,
-        &hap_instance);
+                                            &hap_instance);
     if (FAILED(ret)) {
         return 0;
     }
     ret = IDirectInputDevice8_GetDeviceInfo(joystick->hwdata->InputDevice,
-        &joy_instance);
+                                            &joy_instance);
     if (FAILED(ret)) {
         return 0;
     }
@@ -469,8 +466,7 @@ SDL_DINPUT_JoystickSameHaptic(SDL_Haptic * haptic, SDL_Joystick * joystick)
     return WIN_IsEqualGUID(&hap_instance.guidInstance, &joy_instance.guidInstance);
 }
 
-int
-SDL_DINPUT_HapticOpenFromJoystick(SDL_Haptic * haptic, SDL_Joystick * joystick)
+int SDL_DINPUT_HapticOpenFromJoystick(SDL_Haptic *haptic, SDL_Joystick *joystick)
 {
     SDL_hapticlist_item *item;
     int index = 0;
@@ -495,8 +491,7 @@ SDL_DINPUT_HapticOpenFromJoystick(SDL_Haptic * haptic, SDL_Joystick * joystick)
     return SDL_SetError("Couldn't find joystick in haptic device list");
 }
 
-void
-SDL_DINPUT_HapticClose(SDL_Haptic * haptic)
+void SDL_DINPUT_HapticClose(SDL_Haptic *haptic)
 {
     IDirectInputDevice8_Unacquire(haptic->hwdata->device);
 
@@ -506,8 +501,7 @@ SDL_DINPUT_HapticClose(SDL_Haptic * haptic)
     }
 }
 
-void
-SDL_DINPUT_HapticQuit(void)
+void SDL_DINPUT_HapticQuit(void)
 {
     if (dinput != NULL) {
         IDirectInput8_Release(dinput);
@@ -523,8 +517,7 @@ SDL_DINPUT_HapticQuit(void)
 /*
  * Converts an SDL trigger button to an DIEFFECT trigger button.
  */
-static DWORD
-DIGetTriggerButton(Uint16 button)
+static DWORD DIGetTriggerButton(Uint16 button)
 {
     DWORD dwTriggerButton;
 
@@ -537,18 +530,16 @@ DIGetTriggerButton(Uint16 button)
     return dwTriggerButton;
 }
 
-
 /*
  * Sets the direction.
  */
-static int
-SDL_SYS_SetDirection(DIEFFECT * effect, SDL_HapticDirection * dir, int naxes)
+static int SDL_SYS_SetDirection(DIEFFECT *effect, SDL_HapticDirection *dir, int naxes)
 {
     LONG *rglDir;
 
     /* Handle no axes a part. */
     if (naxes == 0) {
-        effect->dwFlags |= DIEFF_SPHERICAL;     /* Set as default. */
+        effect->dwFlags |= DIEFF_SPHERICAL; /* Set as default. */
         effect->rglDirection = NULL;
         return 0;
     }
@@ -569,18 +560,22 @@ SDL_SYS_SetDirection(DIEFFECT * effect, SDL_HapticDirection * dir, int naxes)
     case SDL_HAPTIC_CARTESIAN:
         effect->dwFlags |= DIEFF_CARTESIAN;
         rglDir[0] = dir->dir[0];
-        if (naxes > 1)
+        if (naxes > 1) {
             rglDir[1] = dir->dir[1];
-        if (naxes > 2)
+        }
+        if (naxes > 2) {
             rglDir[2] = dir->dir[2];
+        }
         return 0;
     case SDL_HAPTIC_SPHERICAL:
         effect->dwFlags |= DIEFF_SPHERICAL;
         rglDir[0] = dir->dir[0];
-        if (naxes > 1)
+        if (naxes > 1) {
             rglDir[1] = dir->dir[1];
-        if (naxes > 2)
+        }
+        if (naxes > 2) {
             rglDir[2] = dir->dir[2];
+        }
         return 0;
     case SDL_HAPTIC_STEERING_AXIS:
         effect->dwFlags |= DIEFF_CARTESIAN;
@@ -593,20 +588,19 @@ SDL_SYS_SetDirection(DIEFFECT * effect, SDL_HapticDirection * dir, int naxes)
 }
 
 /* Clamps and converts. */
-#define CCONVERT(x)   (((x) > 0x7FFF) ? 10000 : ((x)*10000) / 0x7FFF)
+#define CCONVERT(x) (((x) > 0x7FFF) ? 10000 : ((x)*10000) / 0x7FFF)
 /* Just converts. */
-#define CONVERT(x)    (((x)*10000) / 0x7FFF)
+#define CONVERT(x) (((x)*10000) / 0x7FFF)
 /*
  * Creates the DIEFFECT from a SDL_HapticEffect.
  */
-static int
-SDL_SYS_ToDIEFFECT(SDL_Haptic * haptic, DIEFFECT * dest,
-                   SDL_HapticEffect * src)
+static int SDL_SYS_ToDIEFFECT(SDL_Haptic *haptic, DIEFFECT *dest,
+                              SDL_HapticEffect *src)
 {
     int i;
     DICONSTANTFORCE *constant;
     DIPERIODIC *periodic;
-    DICONDITION *condition;     /* Actually an array of conditions - one per axis. */
+    DICONDITION *condition; /* Actually an array of conditions - one per axis. */
     DIRAMPFORCE *ramp;
     DICUSTOMFORCE *custom;
     DIENVELOPE *envelope;
@@ -619,10 +613,10 @@ SDL_SYS_ToDIEFFECT(SDL_Haptic * haptic, DIEFFECT * dest,
 
     /* Set global stuff. */
     SDL_memset(dest, 0, sizeof(DIEFFECT));
-    dest->dwSize = sizeof(DIEFFECT);    /* Set the structure size. */
-    dest->dwSamplePeriod = 0;   /* Not used by us. */
-    dest->dwGain = 10000;       /* Gain is set globally, not locally. */
-    dest->dwFlags = DIEFF_OBJECTOFFSETS;        /* Seems obligatory. */
+    dest->dwSize = sizeof(DIEFFECT);     /* Set the structure size. */
+    dest->dwSamplePeriod = 0;            /* Not used by us. */
+    dest->dwGain = 10000;                /* Gain is set globally, not locally. */
+    dest->dwFlags = DIEFF_OBJECTOFFSETS; /* Seems obligatory. */
 
     /* Envelope. */
     envelope = SDL_malloc(sizeof(DIENVELOPE));
@@ -631,7 +625,7 @@ SDL_SYS_ToDIEFFECT(SDL_Haptic * haptic, DIEFFECT * dest,
     }
     SDL_memset(envelope, 0, sizeof(DIENVELOPE));
     dest->lpEnvelope = envelope;
-    envelope->dwSize = sizeof(DIENVELOPE);      /* Always should be this. */
+    envelope->dwSize = sizeof(DIENVELOPE); /* Always should be this. */
 
     /* Axes. */
     if (src->constant.direction.type == SDL_HAPTIC_STEERING_AXIS) {
@@ -644,7 +638,7 @@ SDL_SYS_ToDIEFFECT(SDL_Haptic * haptic, DIEFFECT * dest,
         if (axes == NULL) {
             return SDL_OutOfMemory();
         }
-        axes[0] = haptic->hwdata->axes[0];      /* Always at least one axis. */
+        axes[0] = haptic->hwdata->axes[0]; /* Always at least one axis. */
         if (dest->cAxes > 1) {
             axes[1] = haptic->hwdata->axes[1];
         }
@@ -670,10 +664,10 @@ SDL_SYS_ToDIEFFECT(SDL_Haptic * haptic, DIEFFECT * dest,
         dest->lpvTypeSpecificParams = constant;
 
         /* Generics */
-        dest->dwDuration = hap_constant->length * 1000; /* In microseconds. */
+        dest->dwDuration = hap_constant->length * 1000UL; /* In microseconds. */
         dest->dwTriggerButton = DIGetTriggerButton(hap_constant->button);
         dest->dwTriggerRepeatInterval = hap_constant->interval;
-        dest->dwStartDelay = hap_constant->delay * 1000;        /* In microseconds. */
+        dest->dwStartDelay = hap_constant->delay * 1000UL; /* In microseconds. */
 
         /* Direction. */
         if (SDL_SYS_SetDirection(dest, &hap_constant->direction, dest->cAxes) < 0) {
@@ -681,15 +675,14 @@ SDL_SYS_ToDIEFFECT(SDL_Haptic * haptic, DIEFFECT * dest,
         }
 
         /* Envelope */
-        if ((hap_constant->attack_length == 0)
-            && (hap_constant->fade_length == 0)) {
+        if ((hap_constant->attack_length == 0) && (hap_constant->fade_length == 0)) {
             SDL_free(dest->lpEnvelope);
             dest->lpEnvelope = NULL;
         } else {
             envelope->dwAttackLevel = CCONVERT(hap_constant->attack_level);
-            envelope->dwAttackTime = hap_constant->attack_length * 1000;
+            envelope->dwAttackTime = hap_constant->attack_length * 1000UL;
             envelope->dwFadeLevel = CCONVERT(hap_constant->fade_level);
-            envelope->dwFadeTime = hap_constant->fade_length * 1000;
+            envelope->dwFadeTime = hap_constant->fade_length * 1000UL;
         }
 
         break;
@@ -711,33 +704,31 @@ SDL_SYS_ToDIEFFECT(SDL_Haptic * haptic, DIEFFECT * dest,
         periodic->dwMagnitude = CONVERT(SDL_abs(hap_periodic->magnitude));
         periodic->lOffset = CONVERT(hap_periodic->offset);
         periodic->dwPhase =
-                (hap_periodic->phase + (hap_periodic->magnitude < 0 ? 18000 : 0)) % 36000;
+            (hap_periodic->phase + (hap_periodic->magnitude < 0 ? 18000 : 0)) % 36000;
         periodic->dwPeriod = hap_periodic->period * 1000;
         dest->cbTypeSpecificParams = sizeof(DIPERIODIC);
         dest->lpvTypeSpecificParams = periodic;
 
         /* Generics */
-        dest->dwDuration = hap_periodic->length * 1000; /* In microseconds. */
+        dest->dwDuration = hap_periodic->length * 1000UL; /* In microseconds. */
         dest->dwTriggerButton = DIGetTriggerButton(hap_periodic->button);
         dest->dwTriggerRepeatInterval = hap_periodic->interval;
-        dest->dwStartDelay = hap_periodic->delay * 1000;        /* In microseconds. */
+        dest->dwStartDelay = hap_periodic->delay * 1000UL; /* In microseconds. */
 
         /* Direction. */
-        if (SDL_SYS_SetDirection(dest, &hap_periodic->direction, dest->cAxes)
-            < 0) {
+        if (SDL_SYS_SetDirection(dest, &hap_periodic->direction, dest->cAxes) < 0) {
             return -1;
         }
 
         /* Envelope */
-        if ((hap_periodic->attack_length == 0)
-            && (hap_periodic->fade_length == 0)) {
+        if ((hap_periodic->attack_length == 0) && (hap_periodic->fade_length == 0)) {
             SDL_free(dest->lpEnvelope);
             dest->lpEnvelope = NULL;
         } else {
             envelope->dwAttackLevel = CCONVERT(hap_periodic->attack_level);
-            envelope->dwAttackTime = hap_periodic->attack_length * 1000;
+            envelope->dwAttackTime = hap_periodic->attack_length * 1000UL;
             envelope->dwFadeLevel = CCONVERT(hap_periodic->fade_level);
-            envelope->dwFadeTime = hap_periodic->fade_length * 1000;
+            envelope->dwFadeTime = hap_periodic->fade_length * 1000UL;
         }
 
         break;
@@ -754,7 +745,7 @@ SDL_SYS_ToDIEFFECT(SDL_Haptic * haptic, DIEFFECT * dest,
         SDL_memset(condition, 0, sizeof(DICONDITION));
 
         /* Specifics */
-        for (i = 0; i < (int) dest->cAxes; i++) {
+        for (i = 0; i < (int)dest->cAxes; i++) {
             condition[i].lOffset = CONVERT(hap_condition->center[i]);
             condition[i].lPositiveCoefficient =
                 CONVERT(hap_condition->right_coeff[i]);
@@ -770,14 +761,13 @@ SDL_SYS_ToDIEFFECT(SDL_Haptic * haptic, DIEFFECT * dest,
         dest->lpvTypeSpecificParams = condition;
 
         /* Generics */
-        dest->dwDuration = hap_condition->length * 1000;        /* In microseconds. */
+        dest->dwDuration = hap_condition->length * 1000UL; /* In microseconds. */
         dest->dwTriggerButton = DIGetTriggerButton(hap_condition->button);
         dest->dwTriggerRepeatInterval = hap_condition->interval;
-        dest->dwStartDelay = hap_condition->delay * 1000;       /* In microseconds. */
+        dest->dwStartDelay = hap_condition->delay * 1000UL; /* In microseconds. */
 
         /* Direction. */
-        if (SDL_SYS_SetDirection(dest, &hap_condition->direction, dest->cAxes)
-            < 0) {
+        if (SDL_SYS_SetDirection(dest, &hap_condition->direction, dest->cAxes) < 0) {
             return -1;
         }
 
@@ -802,10 +792,10 @@ SDL_SYS_ToDIEFFECT(SDL_Haptic * haptic, DIEFFECT * dest,
         dest->lpvTypeSpecificParams = ramp;
 
         /* Generics */
-        dest->dwDuration = hap_ramp->length * 1000;     /* In microseconds. */
+        dest->dwDuration = hap_ramp->length * 1000UL; /* In microseconds. */
         dest->dwTriggerButton = DIGetTriggerButton(hap_ramp->button);
         dest->dwTriggerRepeatInterval = hap_ramp->interval;
-        dest->dwStartDelay = hap_ramp->delay * 1000;    /* In microseconds. */
+        dest->dwStartDelay = hap_ramp->delay * 1000UL; /* In microseconds. */
 
         /* Direction. */
         if (SDL_SYS_SetDirection(dest, &hap_ramp->direction, dest->cAxes) < 0) {
@@ -818,9 +808,9 @@ SDL_SYS_ToDIEFFECT(SDL_Haptic * haptic, DIEFFECT * dest,
             dest->lpEnvelope = NULL;
         } else {
             envelope->dwAttackLevel = CCONVERT(hap_ramp->attack_level);
-            envelope->dwAttackTime = hap_ramp->attack_length * 1000;
+            envelope->dwAttackTime = hap_ramp->attack_length * 1000UL;
             envelope->dwFadeLevel = CCONVERT(hap_ramp->fade_level);
-            envelope->dwFadeTime = hap_ramp->fade_length * 1000;
+            envelope->dwFadeTime = hap_ramp->fade_length * 1000UL;
         }
 
         break;
@@ -835,21 +825,21 @@ SDL_SYS_ToDIEFFECT(SDL_Haptic * haptic, DIEFFECT * dest,
 
         /* Specifics */
         custom->cChannels = hap_custom->channels;
-        custom->dwSamplePeriod = hap_custom->period * 1000;
+        custom->dwSamplePeriod = hap_custom->period * 1000UL;
         custom->cSamples = hap_custom->samples;
         custom->rglForceData =
             SDL_malloc(sizeof(LONG) * custom->cSamples * custom->cChannels);
-        for (i = 0; i < hap_custom->samples * hap_custom->channels; i++) {      /* Copy data. */
+        for (i = 0; i < hap_custom->samples * hap_custom->channels; i++) { /* Copy data. */
             custom->rglForceData[i] = CCONVERT(hap_custom->data[i]);
         }
         dest->cbTypeSpecificParams = sizeof(DICUSTOMFORCE);
         dest->lpvTypeSpecificParams = custom;
 
         /* Generics */
-        dest->dwDuration = hap_custom->length * 1000;   /* In microseconds. */
+        dest->dwDuration = hap_custom->length * 1000UL; /* In microseconds. */
         dest->dwTriggerButton = DIGetTriggerButton(hap_custom->button);
         dest->dwTriggerRepeatInterval = hap_custom->interval;
-        dest->dwStartDelay = hap_custom->delay * 1000;  /* In microseconds. */
+        dest->dwStartDelay = hap_custom->delay * 1000UL; /* In microseconds. */
 
         /* Direction. */
         if (SDL_SYS_SetDirection(dest, &hap_custom->direction, dest->cAxes) < 0) {
@@ -857,15 +847,14 @@ SDL_SYS_ToDIEFFECT(SDL_Haptic * haptic, DIEFFECT * dest,
         }
 
         /* Envelope */
-        if ((hap_custom->attack_length == 0)
-            && (hap_custom->fade_length == 0)) {
+        if ((hap_custom->attack_length == 0) && (hap_custom->fade_length == 0)) {
             SDL_free(dest->lpEnvelope);
             dest->lpEnvelope = NULL;
         } else {
             envelope->dwAttackLevel = CCONVERT(hap_custom->attack_level);
-            envelope->dwAttackTime = hap_custom->attack_length * 1000;
+            envelope->dwAttackTime = hap_custom->attack_length * 1000UL;
             envelope->dwFadeLevel = CCONVERT(hap_custom->fade_level);
-            envelope->dwFadeTime = hap_custom->fade_length * 1000;
+            envelope->dwFadeTime = hap_custom->fade_length * 1000UL;
         }
 
         break;
@@ -877,12 +866,10 @@ SDL_SYS_ToDIEFFECT(SDL_Haptic * haptic, DIEFFECT * dest,
     return 0;
 }
 
-
 /*
  * Frees an DIEFFECT allocated by SDL_SYS_ToDIEFFECT.
  */
-static void
-SDL_SYS_HapticFreeDIEFFECT(DIEFFECT * effect, int type)
+static void SDL_SYS_HapticFreeDIEFFECT(DIEFFECT *effect, int type)
 {
     DICUSTOMFORCE *custom;
 
@@ -891,8 +878,8 @@ SDL_SYS_HapticFreeDIEFFECT(DIEFFECT * effect, int type)
     SDL_free(effect->rgdwAxes);
     effect->rgdwAxes = NULL;
     if (effect->lpvTypeSpecificParams != NULL) {
-        if (type == SDL_HAPTIC_CUSTOM) {        /* Must free the custom data. */
-            custom = (DICUSTOMFORCE *) effect->lpvTypeSpecificParams;
+        if (type == SDL_HAPTIC_CUSTOM) { /* Must free the custom data. */
+            custom = (DICUSTOMFORCE *)effect->lpvTypeSpecificParams;
             SDL_free(custom->rglForceData);
             custom->rglForceData = NULL;
         }
@@ -906,8 +893,8 @@ SDL_SYS_HapticFreeDIEFFECT(DIEFFECT * effect, int type)
 /*
  * Gets the effect type from the generic SDL haptic effect wrapper.
  */
-static REFGUID
-SDL_SYS_HapticEffectType(SDL_HapticEffect * effect)
+/* NOLINTNEXTLINE(readability-const-return-type): Can't fix Windows' headers */
+static REFGUID SDL_SYS_HapticEffectType(SDL_HapticEffect *effect)
 {
     switch (effect->type) {
     case SDL_HAPTIC_CONSTANT:
@@ -916,9 +903,9 @@ SDL_SYS_HapticEffectType(SDL_HapticEffect * effect)
     case SDL_HAPTIC_RAMP:
         return &GUID_RampForce;
 
-    /* !!! FIXME: put this back when we have more bits in 2.1 */
-    /* case SDL_HAPTIC_SQUARE:
-        return &GUID_Square; */
+        /* !!! FIXME: put this back when we have more bits in 2.1 */
+        /* case SDL_HAPTIC_SQUARE:
+            return &GUID_Square; */
 
     case SDL_HAPTIC_SINE:
         return &GUID_Sine;
@@ -951,8 +938,7 @@ SDL_SYS_HapticEffectType(SDL_HapticEffect * effect)
         return NULL;
     }
 }
-int
-SDL_DINPUT_HapticNewEffect(SDL_Haptic * haptic, struct haptic_effect *effect, SDL_HapticEffect * base)
+int SDL_DINPUT_HapticNewEffect(SDL_Haptic *haptic, struct haptic_effect *effect, SDL_HapticEffect *base)
 {
     HRESULT ret;
     REFGUID type = SDL_SYS_HapticEffectType(base);
@@ -968,8 +954,8 @@ SDL_DINPUT_HapticNewEffect(SDL_Haptic * haptic, struct haptic_effect *effect, SD
 
     /* Create the actual effect. */
     ret = IDirectInputDevice8_CreateEffect(haptic->hwdata->device, type,
-        &effect->hweffect->effect,
-        &effect->hweffect->ref, NULL);
+                                           &effect->hweffect->effect,
+                                           &effect->hweffect->ref, NULL);
     if (FAILED(ret)) {
         DI_SetError("Unable to create effect", ret);
         goto err_effectdone;
@@ -982,8 +968,7 @@ err_effectdone:
     return -1;
 }
 
-int
-SDL_DINPUT_HapticUpdateEffect(SDL_Haptic * haptic, struct haptic_effect *effect, SDL_HapticEffect * data)
+int SDL_DINPUT_HapticUpdateEffect(SDL_Haptic *haptic, struct haptic_effect *effect, SDL_HapticEffect *data)
 {
     HRESULT ret;
     DWORD flags;
@@ -996,13 +981,13 @@ SDL_DINPUT_HapticUpdateEffect(SDL_Haptic * haptic, struct haptic_effect *effect,
     }
 
     /* Set the flags.  Might be worthwhile to diff temp with loaded effect and
-    *  only change those parameters. */
+     *  only change those parameters. */
     flags = DIEP_DIRECTION |
-        DIEP_DURATION |
-        DIEP_ENVELOPE |
-        DIEP_STARTDELAY |
-        DIEP_TRIGGERBUTTON |
-        DIEP_TRIGGERREPEATINTERVAL | DIEP_TYPESPECIFICPARAMS;
+            DIEP_DURATION |
+            DIEP_ENVELOPE |
+            DIEP_STARTDELAY |
+            DIEP_TRIGGERBUTTON |
+            DIEP_TRIGGERREPEATINTERVAL | DIEP_TYPESPECIFICPARAMS;
 
     /* Create the actual effect. */
     ret =
@@ -1036,8 +1021,7 @@ err_update:
     return -1;
 }
 
-int
-SDL_DINPUT_HapticRunEffect(SDL_Haptic * haptic, struct haptic_effect *effect, Uint32 iterations)
+int SDL_DINPUT_HapticRunEffect(SDL_Haptic *haptic, struct haptic_effect *effect, Uint32 iterations)
 {
     HRESULT ret;
     DWORD iter;
@@ -1057,8 +1041,7 @@ SDL_DINPUT_HapticRunEffect(SDL_Haptic * haptic, struct haptic_effect *effect, Ui
     return 0;
 }
 
-int
-SDL_DINPUT_HapticStopEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
+int SDL_DINPUT_HapticStopEffect(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
     HRESULT ret;
 
@@ -1069,8 +1052,7 @@ SDL_DINPUT_HapticStopEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
     return 0;
 }
 
-void
-SDL_DINPUT_HapticDestroyEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
+void SDL_DINPUT_HapticDestroyEffect(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
     HRESULT ret;
 
@@ -1081,8 +1063,7 @@ SDL_DINPUT_HapticDestroyEffect(SDL_Haptic * haptic, struct haptic_effect *effect
     SDL_SYS_HapticFreeDIEFFECT(&effect->hweffect->effect, effect->effect.type);
 }
 
-int
-SDL_DINPUT_HapticGetEffectStatus(SDL_Haptic * haptic, struct haptic_effect *effect)
+int SDL_DINPUT_HapticGetEffectStatus(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
     HRESULT ret;
     DWORD status;
@@ -1092,13 +1073,13 @@ SDL_DINPUT_HapticGetEffectStatus(SDL_Haptic * haptic, struct haptic_effect *effe
         return DI_SetError("Getting effect status", ret);
     }
 
-    if (status == 0)
+    if (status == 0) {
         return SDL_FALSE;
+    }
     return SDL_TRUE;
 }
 
-int
-SDL_DINPUT_HapticSetGain(SDL_Haptic * haptic, int gain)
+int SDL_DINPUT_HapticSetGain(SDL_Haptic *haptic, int gain)
 {
     HRESULT ret;
     DIPROPDWORD dipdw;
@@ -1108,19 +1089,18 @@ SDL_DINPUT_HapticSetGain(SDL_Haptic * haptic, int gain)
     dipdw.diph.dwHeaderSize = sizeof(DIPROPHEADER);
     dipdw.diph.dwObj = 0;
     dipdw.diph.dwHow = DIPH_DEVICE;
-    dipdw.dwData = gain * 100;  /* 0 to 10,000 */
+    dipdw.dwData = (DWORD)gain * 100; /* 0 to 10,000 */
 
     /* Try to set the autocenter. */
     ret = IDirectInputDevice8_SetProperty(haptic->hwdata->device,
-        DIPROP_FFGAIN, &dipdw.diph);
+                                          DIPROP_FFGAIN, &dipdw.diph);
     if (FAILED(ret)) {
         return DI_SetError("Setting gain", ret);
     }
     return 0;
 }
 
-int
-SDL_DINPUT_HapticSetAutocenter(SDL_Haptic * haptic, int autocenter)
+int SDL_DINPUT_HapticSetAutocenter(SDL_Haptic *haptic, int autocenter)
 {
     HRESULT ret;
     DIPROPDWORD dipdw;
@@ -1130,54 +1110,50 @@ SDL_DINPUT_HapticSetAutocenter(SDL_Haptic * haptic, int autocenter)
     dipdw.diph.dwHeaderSize = sizeof(DIPROPHEADER);
     dipdw.diph.dwObj = 0;
     dipdw.diph.dwHow = DIPH_DEVICE;
-    dipdw.dwData = (autocenter == 0) ? DIPROPAUTOCENTER_OFF :
-        DIPROPAUTOCENTER_ON;
+    dipdw.dwData = (autocenter == 0) ? DIPROPAUTOCENTER_OFF : DIPROPAUTOCENTER_ON;
 
     /* Try to set the autocenter. */
     ret = IDirectInputDevice8_SetProperty(haptic->hwdata->device,
-        DIPROP_AUTOCENTER, &dipdw.diph);
+                                          DIPROP_AUTOCENTER, &dipdw.diph);
     if (FAILED(ret)) {
         return DI_SetError("Setting autocenter", ret);
     }
     return 0;
 }
 
-int
-SDL_DINPUT_HapticPause(SDL_Haptic * haptic)
+int SDL_DINPUT_HapticPause(SDL_Haptic *haptic)
 {
     HRESULT ret;
 
     /* Pause the device. */
     ret = IDirectInputDevice8_SendForceFeedbackCommand(haptic->hwdata->device,
-        DISFFC_PAUSE);
+                                                       DISFFC_PAUSE);
     if (FAILED(ret)) {
         return DI_SetError("Pausing the device", ret);
     }
     return 0;
 }
 
-int
-SDL_DINPUT_HapticUnpause(SDL_Haptic * haptic)
+int SDL_DINPUT_HapticUnpause(SDL_Haptic *haptic)
 {
     HRESULT ret;
 
     /* Unpause the device. */
     ret = IDirectInputDevice8_SendForceFeedbackCommand(haptic->hwdata->device,
-        DISFFC_CONTINUE);
+                                                       DISFFC_CONTINUE);
     if (FAILED(ret)) {
         return DI_SetError("Pausing the device", ret);
     }
     return 0;
 }
 
-int
-SDL_DINPUT_HapticStopAll(SDL_Haptic * haptic)
+int SDL_DINPUT_HapticStopAll(SDL_Haptic *haptic)
 {
     HRESULT ret;
 
     /* Try to stop the effects. */
     ret = IDirectInputDevice8_SendForceFeedbackCommand(haptic->hwdata->device,
-        DISFFC_STOPALL);
+                                                       DISFFC_STOPALL);
     if (FAILED(ret)) {
         return DI_SetError("Stopping the device", ret);
     }
@@ -1189,113 +1165,94 @@ SDL_DINPUT_HapticStopAll(SDL_Haptic * haptic)
 typedef struct DIDEVICEINSTANCE DIDEVICEINSTANCE;
 typedef struct SDL_hapticlist_item SDL_hapticlist_item;
 
-int
-SDL_DINPUT_HapticInit(void)
+int SDL_DINPUT_HapticInit(void)
 {
     return 0;
 }
 
-int
-SDL_DINPUT_HapticMaybeAddDevice(const DIDEVICEINSTANCE * pdidInstance)
+int SDL_DINPUT_HapticMaybeAddDevice(const DIDEVICEINSTANCE *pdidInstance)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_DINPUT_HapticMaybeRemoveDevice(const DIDEVICEINSTANCE * pdidInstance)
+int SDL_DINPUT_HapticMaybeRemoveDevice(const DIDEVICEINSTANCE *pdidInstance)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_DINPUT_HapticOpen(SDL_Haptic * haptic, SDL_hapticlist_item *item)
+int SDL_DINPUT_HapticOpen(SDL_Haptic *haptic, SDL_hapticlist_item *item)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_DINPUT_JoystickSameHaptic(SDL_Haptic * haptic, SDL_Joystick * joystick)
+int SDL_DINPUT_JoystickSameHaptic(SDL_Haptic *haptic, SDL_Joystick *joystick)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_DINPUT_HapticOpenFromJoystick(SDL_Haptic * haptic, SDL_Joystick * joystick)
+int SDL_DINPUT_HapticOpenFromJoystick(SDL_Haptic *haptic, SDL_Joystick *joystick)
 {
     return SDL_Unsupported();
 }
 
-void
-SDL_DINPUT_HapticClose(SDL_Haptic * haptic)
+void SDL_DINPUT_HapticClose(SDL_Haptic *haptic)
 {
 }
 
-void
-SDL_DINPUT_HapticQuit(void)
+void SDL_DINPUT_HapticQuit(void)
 {
 }
 
-int
-SDL_DINPUT_HapticNewEffect(SDL_Haptic * haptic, struct haptic_effect *effect, SDL_HapticEffect * base)
+int SDL_DINPUT_HapticNewEffect(SDL_Haptic *haptic, struct haptic_effect *effect, SDL_HapticEffect *base)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_DINPUT_HapticUpdateEffect(SDL_Haptic * haptic, struct haptic_effect *effect, SDL_HapticEffect * data)
+int SDL_DINPUT_HapticUpdateEffect(SDL_Haptic *haptic, struct haptic_effect *effect, SDL_HapticEffect *data)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_DINPUT_HapticRunEffect(SDL_Haptic * haptic, struct haptic_effect *effect, Uint32 iterations)
+int SDL_DINPUT_HapticRunEffect(SDL_Haptic *haptic, struct haptic_effect *effect, Uint32 iterations)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_DINPUT_HapticStopEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
+int SDL_DINPUT_HapticStopEffect(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
     return SDL_Unsupported();
 }
 
-void
-SDL_DINPUT_HapticDestroyEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
+void SDL_DINPUT_HapticDestroyEffect(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
 }
 
-int
-SDL_DINPUT_HapticGetEffectStatus(SDL_Haptic * haptic, struct haptic_effect *effect)
+int SDL_DINPUT_HapticGetEffectStatus(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_DINPUT_HapticSetGain(SDL_Haptic * haptic, int gain)
+int SDL_DINPUT_HapticSetGain(SDL_Haptic *haptic, int gain)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_DINPUT_HapticSetAutocenter(SDL_Haptic * haptic, int autocenter)
+int SDL_DINPUT_HapticSetAutocenter(SDL_Haptic *haptic, int autocenter)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_DINPUT_HapticPause(SDL_Haptic * haptic)
+int SDL_DINPUT_HapticPause(SDL_Haptic *haptic)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_DINPUT_HapticUnpause(SDL_Haptic * haptic)
+int SDL_DINPUT_HapticUnpause(SDL_Haptic *haptic)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_DINPUT_HapticStopAll(SDL_Haptic * haptic)
+int SDL_DINPUT_HapticStopAll(SDL_Haptic *haptic)
 {
     return SDL_Unsupported();
 }
