@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -35,12 +35,12 @@ extern "C" {
 /* The SDL joystick structure */
 typedef struct _SDL_JoystickAxisInfo
 {
-    Sint16 initial_value;       /* Initial axis state */
-    Sint16 value;               /* Current axis state */
-    Sint16 zero;                /* Zero point on the axis (-32768 for triggers) */
-    SDL_bool has_initial_value; /* Whether we've seen a value on the axis yet */
-    SDL_bool has_second_value;  /* Whether we've seen a second value on the axis yet */
-    SDL_bool sent_initial_value; /* Whether we've sent the initial axis value */
+    Sint16 initial_value;           /* Initial axis state */
+    Sint16 value;                   /* Current axis state */
+    Sint16 zero;                    /* Zero point on the axis (-32768 for triggers) */
+    SDL_bool has_initial_value;     /* Whether we've seen a value on the axis yet */
+    SDL_bool has_second_value;      /* Whether we've seen a second value on the axis yet */
+    SDL_bool sent_initial_value;    /* Whether we've sent the initial axis value */
     SDL_bool sending_initial_value; /* Whether we are sending the initial axis value */
 } SDL_JoystickAxisInfo;
 
@@ -63,79 +63,89 @@ typedef struct _SDL_JoystickSensorInfo
     SDL_SensorType type;
     SDL_bool enabled;
     float rate;
-    float data[3];      /* If this needs to expand, update SDL_ControllerSensorEvent */
+    float data[3]; /* If this needs to expand, update SDL_ControllerSensorEvent */
+    Uint64 timestamp_us;
 } SDL_JoystickSensorInfo;
 
+#define _guarded SDL_GUARDED_BY(SDL_joystick_lock)
+
 struct _SDL_Joystick
 {
-    SDL_JoystickID instance_id; /* Device instance, monotonically increasing from 0 */
-    char *name;                 /* Joystick name - system dependent */
-    char *path;                 /* Joystick path - system dependent */
-    char *serial;               /* Joystick serial */
-    SDL_JoystickGUID guid;      /* Joystick guid */
-    Uint16 firmware_version;    /* Firmware version, if available */
+    const void *magic _guarded;
 
-    int naxes;                  /* Number of axis controls on the joystick */
-    SDL_JoystickAxisInfo *axes;
+    SDL_JoystickID instance_id _guarded; /* Device instance, monotonically increasing from 0 */
+    char *name _guarded;                 /* Joystick name - system dependent */
+    char *path _guarded;                 /* Joystick path - system dependent */
+    char *serial _guarded;               /* Joystick serial */
+    SDL_JoystickGUID guid _guarded;      /* Joystick guid */
+    Uint16 firmware_version _guarded;    /* Firmware version, if available */
 
-    int nhats;                  /* Number of hats on the joystick */
-    Uint8 *hats;                /* Current hat states */
+    int naxes _guarded; /* Number of axis controls on the joystick */
+    SDL_JoystickAxisInfo *axes _guarded;
 
-    int nballs;                 /* Number of trackballs on the joystick */
-    struct balldelta {
+    int nhats _guarded;   /* Number of hats on the joystick */
+    Uint8 *hats _guarded; /* Current hat states */
+
+    int nballs _guarded; /* Number of trackballs on the joystick */
+    struct balldelta
+    {
         int dx;
         int dy;
-    } *balls;                   /* Current ball motion deltas */
+    } *balls _guarded; /* Current ball motion deltas */
 
-    int nbuttons;               /* Number of buttons on the joystick */
-    Uint8 *buttons;             /* Current button states */
+    int nbuttons _guarded;   /* Number of buttons on the joystick */
+    Uint8 *buttons _guarded; /* Current button states */
 
-    int ntouchpads;             /* Number of touchpads on the joystick */
-    SDL_JoystickTouchpadInfo *touchpads;    /* Current touchpad states */
+    int ntouchpads _guarded;                      /* Number of touchpads on the joystick */
+    SDL_JoystickTouchpadInfo *touchpads _guarded; /* Current touchpad states */
 
-    int nsensors;               /* Number of sensors on the joystick */
-    int nsensors_enabled;
-    SDL_JoystickSensorInfo *sensors;
+    int nsensors _guarded; /* Number of sensors on the joystick */
+    int nsensors_enabled _guarded;
+    SDL_JoystickSensorInfo *sensors _guarded;
 
-    Uint16 low_frequency_rumble;
-    Uint16 high_frequency_rumble;
-    Uint32 rumble_expiration;
+    Uint16 low_frequency_rumble _guarded;
+    Uint16 high_frequency_rumble _guarded;
+    Uint32 rumble_expiration _guarded;
+    Uint32 rumble_resend _guarded;
 
-    Uint16 left_trigger_rumble;
-    Uint16 right_trigger_rumble;
-    Uint32 trigger_rumble_expiration;
+    Uint16 left_trigger_rumble _guarded;
+    Uint16 right_trigger_rumble _guarded;
+    Uint32 trigger_rumble_expiration _guarded;
 
-    Uint8 led_red;
-    Uint8 led_green;
-    Uint8 led_blue;
-    Uint32 led_expiration;
+    Uint8 led_red _guarded;
+    Uint8 led_green _guarded;
+    Uint8 led_blue _guarded;
+    Uint32 led_expiration _guarded;
 
-    SDL_bool attached;
-    SDL_bool is_game_controller;
-    SDL_bool delayed_guide_button; /* SDL_TRUE if this device has the guide button event delayed */
-    SDL_JoystickPowerLevel epowerlevel; /* power level of this joystick, SDL_JOYSTICK_POWER_UNKNOWN if not supported */
+    SDL_bool attached _guarded;
+    SDL_bool is_game_controller _guarded;
+    SDL_bool delayed_guide_button _guarded;      /* SDL_TRUE if this device has the guide button event delayed */
+    SDL_JoystickPowerLevel epowerlevel _guarded; /* power level of this joystick, SDL_JOYSTICK_POWER_UNKNOWN if not supported */
 
-    struct _SDL_JoystickDriver *driver;
+    struct _SDL_JoystickDriver *driver _guarded;
 
-    struct joystick_hwdata *hwdata;     /* Driver dependent information */
+    struct joystick_hwdata *hwdata _guarded; /* Driver dependent information */
 
-    int ref_count;              /* Reference count for multiple opens */
+    int ref_count _guarded; /* Reference count for multiple opens */
 
-    struct _SDL_Joystick *next; /* pointer to next joystick we have allocated */
+    struct _SDL_Joystick *next _guarded; /* pointer to next joystick we have allocated */
 };
 
+#undef _guarded
+
 /* Device bus definitions */
-#define SDL_HARDWARE_BUS_VIRTUAL    0x00
-#define SDL_HARDWARE_BUS_USB        0x03
-#define SDL_HARDWARE_BUS_BLUETOOTH  0x05
+#define SDL_HARDWARE_BUS_UNKNOWN   0x00
+#define SDL_HARDWARE_BUS_USB       0x03
+#define SDL_HARDWARE_BUS_BLUETOOTH 0x05
+#define SDL_HARDWARE_BUS_VIRTUAL   0xFF
 
 /* Joystick capability flags for GetCapabilities() */
-#define SDL_JOYCAP_LED              0x01
-#define SDL_JOYCAP_RUMBLE           0x02
-#define SDL_JOYCAP_RUMBLE_TRIGGERS  0x04
+#define SDL_JOYCAP_LED             0x01
+#define SDL_JOYCAP_RUMBLE          0x02
+#define SDL_JOYCAP_RUMBLE_TRIGGERS 0x04
 
 /* Macro to combine a USB vendor ID and product ID into a single Uint32 value */
-#define MAKE_VIDPID(VID, PID)   (((Uint32)(VID))<<16|(PID))
+#define MAKE_VIDPID(VID, PID) (((Uint32)(VID)) << 16 | (PID))
 
 typedef struct _SDL_JoystickDriver
 {
@@ -206,14 +216,18 @@ typedef struct _SDL_JoystickDriver
     void (*Quit)(void);
 
     /* Function to get the autodetected controller mapping; returns false if there isn't any. */
-    SDL_bool (*GetGamepadMapping)(int device_index, SDL_GamepadMapping * out);
+    SDL_bool (*GetGamepadMapping)(int device_index, SDL_GamepadMapping *out);
 
 } SDL_JoystickDriver;
 
 /* Windows and Mac OSX has a limit of MAX_DWORD / 1000, Linux kernel has a limit of 0xFFFF */
-#define SDL_MAX_RUMBLE_DURATION_MS  0xFFFF
+#define SDL_MAX_RUMBLE_DURATION_MS 0xFFFF
 
-#define SDL_LED_MIN_REPEAT_MS  5000
+/* Dualshock4 only rumbles for about 5 seconds max, resend rumble command every 2 seconds
+ * to make long rumble work. */
+#define SDL_RUMBLE_RESEND_MS 2000
+
+#define SDL_LED_MIN_REPEAT_MS 5000
 
 /* The available joystick drivers */
 extern SDL_JoystickDriver SDL_ANDROID_JoystickDriver;
@@ -234,6 +248,7 @@ extern SDL_JoystickDriver SDL_OS2_JoystickDriver;
 extern SDL_JoystickDriver SDL_PS2_JoystickDriver;
 extern SDL_JoystickDriver SDL_PSP_JoystickDriver;
 extern SDL_JoystickDriver SDL_VITA_JoystickDriver;
+extern SDL_JoystickDriver SDL_N3DS_JoystickDriver;
 
 /* Ends C function definitions when using C++ */
 #ifdef __cplusplus
