@@ -1654,8 +1654,22 @@ static SDL_Renderer *METAL_CreateRenderer(SDL_Window * window, Uint32 flags)
         return NULL;
     }
 
-    // !!! FIXME: MTLCopyAllDevices() can find other GPUs on macOS...
-    mtldevice = MTLCreateSystemDefaultDevice();
+#ifdef __MACOSX__
+    if (SDL_GetHintBoolean(SDL_HINT_RENDER_METAL_PREFER_LOW_POWER_DEVICE, SDL_TRUE)) {
+        NSArray<id<MTLDevice>> *devices = MTLCopyAllDevices();
+
+        for (id<MTLDevice> device in devices) {
+            if (device.isLowPower) {
+                mtldevice = device;
+                break;
+            }
+        }
+    }
+#endif
+
+    if (mtldevice == nil) {
+        mtldevice = MTLCreateSystemDefaultDevice();
+    }
 
     if (mtldevice == nil) {
         SDL_free(renderer);
