@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -34,49 +34,47 @@
 
 /* Copied from vc_vchi_dispmanx.h which is bugged and tries to include a non existing file */
 /* Attributes changes flag mask */
-#define ELEMENT_CHANGE_LAYER          (1<<0)
-#define ELEMENT_CHANGE_OPACITY        (1<<1)
-#define ELEMENT_CHANGE_DEST_RECT      (1<<2)
-#define ELEMENT_CHANGE_SRC_RECT       (1<<3)
-#define ELEMENT_CHANGE_MASK_RESOURCE  (1<<4)
-#define ELEMENT_CHANGE_TRANSFORM      (1<<5)
+#define ELEMENT_CHANGE_LAYER         (1 << 0)
+#define ELEMENT_CHANGE_OPACITY       (1 << 1)
+#define ELEMENT_CHANGE_DEST_RECT     (1 << 2)
+#define ELEMENT_CHANGE_SRC_RECT      (1 << 3)
+#define ELEMENT_CHANGE_MASK_RESOURCE (1 << 4)
+#define ELEMENT_CHANGE_TRANSFORM     (1 << 5)
 /* End copied from vc_vchi_dispmanx.h */
 
 static SDL_Cursor *RPI_CreateDefaultCursor(void);
-static SDL_Cursor *RPI_CreateCursor(SDL_Surface * surface, int hot_x, int hot_y);
-static int RPI_ShowCursor(SDL_Cursor * cursor);
-static void RPI_MoveCursor(SDL_Cursor * cursor);
-static void RPI_FreeCursor(SDL_Cursor * cursor);
-static void RPI_WarpMouse(SDL_Window * window, int x, int y);
+static SDL_Cursor *RPI_CreateCursor(SDL_Surface *surface, int hot_x, int hot_y);
+static int RPI_ShowCursor(SDL_Cursor *cursor);
+static void RPI_MoveCursor(SDL_Cursor *cursor);
+static void RPI_FreeCursor(SDL_Cursor *cursor);
+static void RPI_WarpMouse(SDL_Window *window, int x, int y);
 static int RPI_WarpMouseGlobal(int x, int y);
 
 static SDL_Cursor *global_cursor;
 
-static SDL_Cursor *
-RPI_CreateDefaultCursor(void)
+static SDL_Cursor *RPI_CreateDefaultCursor(void)
 {
     return SDL_CreateCursor(default_cdata, default_cmask, DEFAULT_CWIDTH, DEFAULT_CHEIGHT, DEFAULT_CHOTX, DEFAULT_CHOTY);
 }
 
 /* Create a cursor from a surface */
-static SDL_Cursor *
-RPI_CreateCursor(SDL_Surface * surface, int hot_x, int hot_y)
+static SDL_Cursor *RPI_CreateCursor(SDL_Surface *surface, int hot_x, int hot_y)
 {
     RPI_CursorData *curdata;
     SDL_Cursor *cursor;
     int ret;
     VC_RECT_T dst_rect;
     Uint32 dummy;
-        
+
     SDL_assert(surface->format->format == SDL_PIXELFORMAT_ARGB8888);
     SDL_assert(surface->pitch == surface->w * 4);
-    
-    cursor = (SDL_Cursor *) SDL_calloc(1, sizeof(*cursor));
+
+    cursor = (SDL_Cursor *)SDL_calloc(1, sizeof(*cursor));
     if (cursor == NULL) {
         SDL_OutOfMemory();
         return NULL;
     }
-    curdata = (RPI_CursorData *) SDL_calloc(1, sizeof(*curdata));
+    curdata = (RPI_CursorData *)SDL_calloc(1, sizeof(*curdata));
     if (curdata == NULL) {
         SDL_OutOfMemory();
         SDL_free(cursor);
@@ -87,29 +85,27 @@ RPI_CreateCursor(SDL_Surface * surface, int hot_x, int hot_y)
     curdata->hot_y = hot_y;
     curdata->w = surface->w;
     curdata->h = surface->h;
-    
+
     /* This usage is inspired by Wayland/Weston RPI code, how they figured this out is anyone's guess */
     curdata->resource = vc_dispmanx_resource_create(VC_IMAGE_ARGB8888, surface->w | (surface->pitch << 16), surface->h | (surface->h << 16), &dummy);
     SDL_assert(curdata->resource);
     vc_dispmanx_rect_set(&dst_rect, 0, 0, curdata->w, curdata->h);
-    /* A note from Weston: 
+    /* A note from Weston:
      * vc_dispmanx_resource_write_data() ignores ifmt,
      * rect.x, rect.width, and uses stride only for computing
      * the size of the transfer as rect.height * stride.
      * Therefore we can only write rows starting at x=0.
      */
     ret = vc_dispmanx_resource_write_data(curdata->resource, VC_IMAGE_ARGB8888, surface->pitch, surface->pixels, &dst_rect);
-    SDL_assert (ret == DISPMANX_SUCCESS);
-    
-    cursor->driverdata = curdata;
-    
-    return cursor;
+    SDL_assert(ret == DISPMANX_SUCCESS);
 
+    cursor->driverdata = curdata;
+
+    return cursor;
 }
 
 /* Show the specified cursor, or hide if cursor is NULL */
-static int
-RPI_ShowCursor(SDL_Cursor * cursor)
+static int RPI_ShowCursor(SDL_Cursor *cursor)
 {
     int ret;
     DISPMANX_UPDATE_HANDLE_T update;
@@ -118,7 +114,7 @@ RPI_ShowCursor(SDL_Cursor * cursor)
     SDL_Mouse *mouse;
     SDL_VideoDisplay *display;
     SDL_DisplayData *data;
-    VC_DISPMANX_ALPHA_T alpha = {  DISPMANX_FLAGS_ALPHA_FROM_SOURCE /* flags */ , 255 /*opacity 0->255*/,  0 /* mask */ };
+    VC_DISPMANX_ALPHA_T alpha = { DISPMANX_FLAGS_ALPHA_FROM_SOURCE /* flags */, 255 /*opacity 0->255*/, 0 /* mask */ };
     uint32_t layer = SDL_RPI_MOUSELAYER;
     const char *env;
 
@@ -126,10 +122,10 @@ RPI_ShowCursor(SDL_Cursor * cursor)
     if (mouse == NULL) {
         return -1;
     }
-    
+
     if (cursor != global_cursor) {
         if (global_cursor != NULL) {
-            curdata = (RPI_CursorData *) global_cursor->driverdata;
+            curdata = (RPI_CursorData *)global_cursor->driverdata;
             if (curdata && curdata->element > DISPMANX_NO_HANDLE) {
                 update = vc_dispmanx_update_start(0);
                 SDL_assert(update);
@@ -146,12 +142,12 @@ RPI_ShowCursor(SDL_Cursor * cursor)
     if (cursor == NULL) {
         return 0;
     }
-    
-    curdata = (RPI_CursorData *) cursor->driverdata;
+
+    curdata = (RPI_CursorData *)cursor->driverdata;
     if (curdata == NULL) {
         return -1;
     }
-    
+
     if (mouse->focus == NULL) {
         return -1;
     }
@@ -160,16 +156,16 @@ RPI_ShowCursor(SDL_Cursor * cursor)
     if (display == NULL) {
         return -1;
     }
-    
-    data = (SDL_DisplayData*) display->driverdata;
+
+    data = (SDL_DisplayData *)display->driverdata;
     if (data == NULL) {
         return -1;
     }
-    
+
     if (curdata->element == DISPMANX_NO_HANDLE) {
         vc_dispmanx_rect_set(&src_rect, 0, 0, curdata->w << 16, curdata->h << 16);
         vc_dispmanx_rect_set(&dst_rect, mouse->x - curdata->hot_x, mouse->y - curdata->hot_y, curdata->w, curdata->h);
-        
+
         update = vc_dispmanx_update_start(0);
         SDL_assert(update);
 
@@ -179,34 +175,33 @@ RPI_ShowCursor(SDL_Cursor * cursor)
         }
 
         curdata->element = vc_dispmanx_element_add(update,
-                                                    data->dispman_display,
-                                                    layer,
-                                                    &dst_rect,
-                                                    curdata->resource,
-                                                    &src_rect,
-                                                    DISPMANX_PROTECTION_NONE,
-                                                    &alpha,
-                                                    DISPMANX_NO_HANDLE, // clamp
-                                                    DISPMANX_NO_ROTATE);
+                                                   data->dispman_display,
+                                                   layer,
+                                                   &dst_rect,
+                                                   curdata->resource,
+                                                   &src_rect,
+                                                   DISPMANX_PROTECTION_NONE,
+                                                   &alpha,
+                                                   DISPMANX_NO_HANDLE, // clamp
+                                                   DISPMANX_NO_ROTATE);
         SDL_assert(curdata->element > DISPMANX_NO_HANDLE);
         ret = vc_dispmanx_update_submit_sync(update);
         SDL_assert(ret == DISPMANX_SUCCESS);
     }
-    
+
     return 0;
 }
 
 /* Free a window manager cursor */
-static void
-RPI_FreeCursor(SDL_Cursor * cursor)
+static void RPI_FreeCursor(SDL_Cursor *cursor)
 {
     int ret;
     DISPMANX_UPDATE_HANDLE_T update;
     RPI_CursorData *curdata;
-    
+
     if (cursor != NULL) {
-        curdata = (RPI_CursorData *) cursor->driverdata;
-        
+        curdata = (RPI_CursorData *)cursor->driverdata;
+
         if (curdata != NULL) {
             if (curdata->element != DISPMANX_NO_HANDLE) {
                 update = vc_dispmanx_update_start(0);
@@ -216,12 +211,12 @@ RPI_FreeCursor(SDL_Cursor * cursor)
                 ret = vc_dispmanx_update_submit_sync(update);
                 SDL_assert(ret == DISPMANX_SUCCESS);
             }
-            
+
             if (curdata->resource != DISPMANX_NO_HANDLE) {
                 ret = vc_dispmanx_resource_delete(curdata->resource);
                 SDL_assert(ret == DISPMANX_SUCCESS);
             }
-        
+
             SDL_free(cursor->driverdata);
         }
         SDL_free(cursor);
@@ -232,15 +227,13 @@ RPI_FreeCursor(SDL_Cursor * cursor)
 }
 
 /* Warp the mouse to (x,y) */
-static void
-RPI_WarpMouse(SDL_Window * window, int x, int y)
+static void RPI_WarpMouse(SDL_Window *window, int x, int y)
 {
     RPI_WarpMouseGlobal(x, y);
 }
 
 /* Warp the mouse to (x,y) */
-static int
-RPI_WarpMouseGlobal(int x, int y)
+static int RPI_WarpMouseGlobal(int x, int y)
 {
     RPI_CursorData *curdata;
     DISPMANX_UPDATE_HANDLE_T update;
@@ -248,7 +241,7 @@ RPI_WarpMouseGlobal(int x, int y)
     VC_RECT_T dst_rect;
     VC_RECT_T src_rect;
     SDL_Mouse *mouse = SDL_GetMouse();
-    
+
     if (mouse == NULL || mouse->cur_cursor == NULL || mouse->cur_cursor->driverdata == NULL) {
         return 0;
     }
@@ -256,7 +249,7 @@ RPI_WarpMouseGlobal(int x, int y)
     /* Update internal mouse position. */
     SDL_SendMouseMotion(mouse->focus, mouse->mouseID, 0, x, y);
 
-    curdata = (RPI_CursorData *) mouse->cur_cursor->driverdata;
+    curdata = (RPI_CursorData *)mouse->cur_cursor->driverdata;
     if (curdata->element == DISPMANX_NO_HANDLE) {
         return 0;
     }
@@ -268,11 +261,11 @@ RPI_WarpMouseGlobal(int x, int y)
 
     src_rect.x = 0;
     src_rect.y = 0;
-    src_rect.width  = curdata->w << 16;
+    src_rect.width = curdata->w << 16;
     src_rect.height = curdata->h << 16;
     dst_rect.x = x - curdata->hot_x;
     dst_rect.y = y - curdata->hot_y;
-    dst_rect.width  = curdata->w;
+    dst_rect.width = curdata->w;
     dst_rect.height = curdata->h;
 
     ret = vc_dispmanx_element_change_attributes(
@@ -298,8 +291,7 @@ RPI_WarpMouseGlobal(int x, int y)
 }
 
 /* Warp the mouse to (x,y) */
-static int
-RPI_WarpMouseGlobalGraphicOnly(int x, int y)
+static int RPI_WarpMouseGlobalGraphicOnly(int x, int y)
 {
     RPI_CursorData *curdata;
     DISPMANX_UPDATE_HANDLE_T update;
@@ -307,12 +299,12 @@ RPI_WarpMouseGlobalGraphicOnly(int x, int y)
     VC_RECT_T dst_rect;
     VC_RECT_T src_rect;
     SDL_Mouse *mouse = SDL_GetMouse();
-    
+
     if (mouse == NULL || mouse->cur_cursor == NULL || mouse->cur_cursor->driverdata == NULL) {
         return 0;
     }
 
-    curdata = (RPI_CursorData *) mouse->cur_cursor->driverdata;
+    curdata = (RPI_CursorData *)mouse->cur_cursor->driverdata;
     if (curdata->element == DISPMANX_NO_HANDLE) {
         return 0;
     }
@@ -324,11 +316,11 @@ RPI_WarpMouseGlobalGraphicOnly(int x, int y)
 
     src_rect.x = 0;
     src_rect.y = 0;
-    src_rect.width  = curdata->w << 16;
+    src_rect.width = curdata->w << 16;
     src_rect.height = curdata->h << 16;
     dst_rect.x = x - curdata->hot_x;
     dst_rect.y = y - curdata->hot_y;
-    dst_rect.width  = curdata->w;
+    dst_rect.width = curdata->w;
     dst_rect.height = curdata->h;
 
     ret = vc_dispmanx_element_change_attributes(
@@ -353,10 +345,9 @@ RPI_WarpMouseGlobalGraphicOnly(int x, int y)
     return 0;
 }
 
-void
-RPI_InitMouse(_THIS)
+void RPI_InitMouse(_THIS)
 {
-    /* FIXME: Using UDEV it should be possible to scan all mice 
+    /* FIXME: Using UDEV it should be possible to scan all mice
      * but there's no point in doing so as there's no multimice support...yet!
      */
     SDL_Mouse *mouse = SDL_GetMouse();
@@ -371,17 +362,15 @@ RPI_InitMouse(_THIS)
     SDL_SetDefaultCursor(RPI_CreateDefaultCursor());
 }
 
-void
-RPI_QuitMouse(_THIS)
+void RPI_QuitMouse(_THIS)
 {
 }
 
 /* This is called when a mouse motion event occurs */
-static void
-RPI_MoveCursor(SDL_Cursor * cursor)
+static void RPI_MoveCursor(SDL_Cursor *cursor)
 {
     SDL_Mouse *mouse = SDL_GetMouse();
-    /* We must NOT call SDL_SendMouseMotion() on the next call or we will enter recursivity, 
+    /* We must NOT call SDL_SendMouseMotion() on the next call or we will enter recursivity,
      * so we create a version of WarpMouseGlobal without it. */
     RPI_WarpMouseGlobalGraphicOnly(mouse->x, mouse->y);
 }
