@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -32,24 +32,24 @@
 #include <kernel.h>
 #include <swis.h>
 
-static SDL_Scancode
-SDL_RISCOS_translate_keycode(int keycode)
+static SDL_Scancode SDL_RISCOS_translate_keycode(int keycode)
 {
     SDL_Scancode scancode = SDL_SCANCODE_UNKNOWN;
 
     if (keycode < SDL_arraysize(riscos_scancode_table)) {
         scancode = riscos_scancode_table[keycode];
 
+#ifdef DEBUG_SCANCODES
         if (scancode == SDL_SCANCODE_UNKNOWN) {
             SDL_Log("The key you just pressed is not recognized by SDL: %d", keycode);
         }
+#endif
     }
 
     return scancode;
 }
 
-void
-RISCOS_PollKeyboard(_THIS)
+void RISCOS_PollKeyboard(_THIS)
 {
     SDL_VideoData *driverdata = (SDL_VideoData *)_this->driverdata;
     Uint8 key = 2;
@@ -109,8 +109,7 @@ static const Uint8 mouse_button_map[] = {
     SDL_BUTTON_X2 + 3
 };
 
-void
-RISCOS_PollMouse(_THIS)
+void RISCOS_PollMouse(_THIS)
 {
     SDL_VideoData *driverdata = (SDL_VideoData *)_this->driverdata;
     SDL_Mouse *mouse = SDL_GetMouse();
@@ -139,21 +138,21 @@ RISCOS_PollMouse(_THIS)
     }
 }
 
-int
-RISCOS_InitEvents(_THIS)
+int RISCOS_InitEvents(_THIS)
 {
-    SDL_VideoData *driverdata = (SDL_VideoData *) _this->driverdata;
+    SDL_VideoData *driverdata = (SDL_VideoData *)_this->driverdata;
     _kernel_swi_regs regs;
     int i, status;
 
-    for (i = 0; i < RISCOS_MAX_KEYS_PRESSED; i++)
+    for (i = 0; i < RISCOS_MAX_KEYS_PRESSED; i++) {
         driverdata->key_pressed[i] = 255;
+    }
 
     status = (_kernel_osbyte(202, 0, 255) & 0xFF);
-    SDL_ToggleModState(KMOD_NUM,    (status & (1 << 2)) == 0);
-    SDL_ToggleModState(KMOD_CAPS,   (status & (1 << 4)) == 0);
-    SDL_ToggleModState(KMOD_SCROLL, (status & (1 << 1)) != 0);
-
+    SDL_ToggleModState(KMOD_NUM, (status & (1 << 2)) ? SDL_FALSE : SDL_TRUE);
+    SDL_ToggleModState(KMOD_CAPS, (status & (1 << 4)) ? SDL_FALSE : SDL_TRUE);
+    SDL_ToggleModState(KMOD_SCROLL, (status & (1 << 1)) ? SDL_TRUE : SDL_FALSE);
+ 
     _kernel_swi(OS_Mouse, &regs, &regs);
     driverdata->last_mouse_buttons = regs.r[2];
 
@@ -163,15 +162,13 @@ RISCOS_InitEvents(_THIS)
     return 0;
 }
 
-void
-RISCOS_PumpEvents(_THIS)
+void RISCOS_PumpEvents(_THIS)
 {
     RISCOS_PollMouse(_this);
     RISCOS_PollKeyboard(_this);
 }
 
-void
-RISCOS_QuitEvents(_THIS)
+void RISCOS_QuitEvents(_THIS)
 {
     /* Re-enable escape. */
     _kernel_osbyte(229, 0, 0);
