@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -26,8 +26,7 @@
 
 #ifdef VIVANTE_PLATFORM_GENERIC
 
-int
-VIVANTE_SetupPlatform(_THIS)
+int VIVANTE_SetupPlatform(_THIS)
 {
     return 0;
 }
@@ -37,13 +36,11 @@ char *VIVANTE_GetDisplayName(_THIS)
     return NULL;
 }
 
-void
-VIVANTE_UpdateDisplayScale(_THIS)
+void VIVANTE_UpdateDisplayScale(_THIS)
 {
 }
 
-void
-VIVANTE_CleanupPlatform(_THIS)
+void VIVANTE_CleanupPlatform(_THIS)
 {
 }
 
