@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2020 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -22,7 +22,6 @@
 
 #if SDL_VIDEO_DRIVER_WINDOWS
 
-#include "SDL_assert.h"
 #include "SDL_loadso.h"
 #include "SDL_windowsvideo.h"
 #include "SDL_windowsopengles.h"
@@ -37,12 +36,12 @@
 
 #ifndef WGL_ARB_create_context
 #define WGL_ARB_create_context
-#define WGL_CONTEXT_MAJOR_VERSION_ARB   0x2091
-#define WGL_CONTEXT_MINOR_VERSION_ARB   0x2092
-#define WGL_CONTEXT_LAYER_PLANE_ARB     0x2093
-#define WGL_CONTEXT_FLAGS_ARB           0x2094
-#define WGL_CONTEXT_DEBUG_BIT_ARB       0x0001
-#define WGL_CONTEXT_FORWARD_COMPATIBLE_BIT_ARB  0x0002
+#define WGL_CONTEXT_MAJOR_VERSION_ARB          0x2091
+#define WGL_CONTEXT_MINOR_VERSION_ARB          0x2092
+#define WGL_CONTEXT_LAYER_PLANE_ARB            0x2093
+#define WGL_CONTEXT_FLAGS_ARB                  0x2094
+#define WGL_CONTEXT_DEBUG_BIT_ARB              0x0001
+#define WGL_CONTEXT_FORWARD_COMPATIBLE_BIT_ARB 0x0002
 
 #ifndef WGL_ARB_create_context_profile
 #define WGL_ARB_create_context_profile
@@ -53,48 +52,62 @@
 
 #ifndef WGL_ARB_create_context_robustness
 #define WGL_ARB_create_context_robustness
-#define WGL_CONTEXT_ROBUST_ACCESS_BIT_ARB         0x00000004
-#define WGL_CONTEXT_RESET_NOTIFICATION_STRATEGY_ARB     0x8256
-#define WGL_NO_RESET_NOTIFICATION_ARB                   0x8261
-#define WGL_LOSE_CONTEXT_ON_RESET_ARB                   0x8252
+#define WGL_CONTEXT_ROBUST_ACCESS_BIT_ARB           0x00000004
+#define WGL_CONTEXT_RESET_NOTIFICATION_STRATEGY_ARB 0x8256
+#define WGL_NO_RESET_NOTIFICATION_ARB               0x8261
+#define WGL_LOSE_CONTEXT_ON_RESET_ARB               0x8252
 #endif
 #endif
 
 #ifndef WGL_EXT_create_context_es2_profile
 #define WGL_EXT_create_context_es2_profile
-#define WGL_CONTEXT_ES2_PROFILE_BIT_EXT           0x00000004
+#define WGL_CONTEXT_ES2_PROFILE_BIT_EXT 0x00000004
 #endif
 
 #ifndef WGL_EXT_create_context_es_profile
 #define WGL_EXT_create_context_es_profile
-#define WGL_CONTEXT_ES_PROFILE_BIT_EXT            0x00000004
+#define WGL_CONTEXT_ES_PROFILE_BIT_EXT 0x00000004
 #endif
 
 #ifndef WGL_ARB_framebuffer_sRGB
 #define WGL_ARB_framebuffer_sRGB
-#define WGL_FRAMEBUFFER_SRGB_CAPABLE_ARB                0x20A9
+#define WGL_FRAMEBUFFER_SRGB_CAPABLE_ARB 0x20A9
+#endif
+
+#ifndef WGL_ARB_pixel_format_float
+#define WGL_ARB_pixel_format_float
+#define WGL_TYPE_RGBA_FLOAT_ARB 0x21A0
 #endif
 
 #ifndef WGL_ARB_context_flush_control
 #define WGL_ARB_context_flush_control
-#define WGL_CONTEXT_RELEASE_BEHAVIOR_ARB   0x2097
-#define WGL_CONTEXT_RELEASE_BEHAVIOR_NONE_ARB           0x0000
-#define WGL_CONTEXT_RELEASE_BEHAVIOR_FLUSH_ARB          0x2098
+#define WGL_CONTEXT_RELEASE_BEHAVIOR_ARB       0x2097
+#define WGL_CONTEXT_RELEASE_BEHAVIOR_NONE_ARB  0x0000
+#define WGL_CONTEXT_RELEASE_BEHAVIOR_FLUSH_ARB 0x2098
 #endif
 
 #ifndef WGL_ARB_create_context_no_error
 #define WGL_ARB_create_context_no_error
-#define WGL_CONTEXT_OPENGL_NO_ERROR_ARB                 0x31B3
+#define WGL_CONTEXT_OPENGL_NO_ERROR_ARB 0x31B3
 #endif
 
-typedef HGLRC(APIENTRYP PFNWGLCREATECONTEXTATTRIBSARBPROC) (HDC hDC,
-                                                            HGLRC
-                                                            hShareContext,
-                                                            const int
-                                                            *attribList);
+typedef HGLRC(APIENTRYP PFNWGLCREATECONTEXTATTRIBSARBPROC)(HDC hDC,
+                                                           HGLRC
+                                                               hShareContext,
+                                                           const int
+                                                               *attribList);
 
-int
-WIN_GL_LoadLibrary(_THIS, const char *path)
+#if __XBOXONE__ || __XBOXSERIES__
+#define GetDC(hwnd)          (HDC) hwnd
+#define ReleaseDC(hwnd, hdc) 1
+#define SwapBuffers          _this->gl_data->wglSwapBuffers
+#define DescribePixelFormat  _this->gl_data->wglDescribePixelFormat
+#define ChoosePixelFormat    _this->gl_data->wglChoosePixelFormat
+#define GetPixelFormat       _this->gl_data->wglGetPixelFormat
+#define SetPixelFormat       _this->gl_data->wglSetPixelFormat
+#endif
+
+int WIN_GL_LoadLibrary(_THIS, const char *path)
 {
     void *handle;
 
@@ -112,28 +125,51 @@ WIN_GL_LoadLibrary(_THIS, const char *path)
                 SDL_arraysize(_this->gl_config.driver_path));
 
     /* Allocate OpenGL memory */
-    _this->gl_data = (struct SDL_GLDriverData *) SDL_calloc(1, sizeof(struct SDL_GLDriverData));
+    _this->gl_data = (struct SDL_GLDriverData *)SDL_calloc(1, sizeof(struct SDL_GLDriverData));
     if (!_this->gl_data) {
         return SDL_OutOfMemory();
     }
 
     /* Load function pointers */
     handle = _this->gl_config.dll_handle;
-    _this->gl_data->wglGetProcAddress = (void *(WINAPI *) (const char *))
+    /* *INDENT-OFF* */ /* clang-format off */
+    _this->gl_data->wglGetProcAddress = (void *(WINAPI *)(const char *))
         SDL_LoadFunction(handle, "wglGetProcAddress");
-    _this->gl_data->wglCreateContext = (HGLRC(WINAPI *) (HDC))
+    _this->gl_data->wglCreateContext = (HGLRC (WINAPI *)(HDC))
         SDL_LoadFunction(handle, "wglCreateContext");
-    _this->gl_data->wglDeleteContext = (BOOL(WINAPI *) (HGLRC))
+    _this->gl_data->wglDeleteContext = (BOOL (WINAPI *)(HGLRC))
         SDL_LoadFunction(handle, "wglDeleteContext");
-    _this->gl_data->wglMakeCurrent = (BOOL(WINAPI *) (HDC, HGLRC))
+    _this->gl_data->wglMakeCurrent = (BOOL (WINAPI *)(HDC, HGLRC))
         SDL_LoadFunction(handle, "wglMakeCurrent");
-    _this->gl_data->wglShareLists = (BOOL(WINAPI *) (HGLRC, HGLRC))
+    _this->gl_data->wglShareLists = (BOOL (WINAPI *)(HGLRC, HGLRC))
         SDL_LoadFunction(handle, "wglShareLists");
+    /* *INDENT-ON* */ /* clang-format on */
+
+#if __XBOXONE__ || __XBOXSERIES__
+    _this->gl_data->wglSwapBuffers = (BOOL(WINAPI *)(HDC))
+        SDL_LoadFunction(handle, "wglSwapBuffers");
+    _this->gl_data->wglDescribePixelFormat = (int(WINAPI *)(HDC, int, UINT, LPPIXELFORMATDESCRIPTOR))
+        SDL_LoadFunction(handle, "wglDescribePixelFormat");
+    _this->gl_data->wglChoosePixelFormat = (int(WINAPI *)(HDC, const PIXELFORMATDESCRIPTOR *))
+        SDL_LoadFunction(handle, "wglChoosePixelFormat");
+    _this->gl_data->wglSetPixelFormat = (BOOL(WINAPI *)(HDC, int, const PIXELFORMATDESCRIPTOR *))
+        SDL_LoadFunction(handle, "wglSetPixelFormat");
+    _this->gl_data->wglGetPixelFormat = (int(WINAPI *)(HDC hdc))
+        SDL_LoadFunction(handle, "wglGetPixelFormat");
+#endif
 
     if (!_this->gl_data->wglGetProcAddress ||
         !_this->gl_data->wglCreateContext ||
         !_this->gl_data->wglDeleteContext ||
-        !_this->gl_data->wglMakeCurrent) {
+        !_this->gl_data->wglMakeCurrent
+#if __XBOXONE__ || __XBOXSERIES__
+        || !_this->gl_data->wglSwapBuffers ||
+        !_this->gl_data->wglDescribePixelFormat ||
+        !_this->gl_data->wglChoosePixelFormat ||
+        !_this->gl_data->wglGetPixelFormat ||
+        !_this->gl_data->wglSetPixelFormat
+#endif
+    ) {
         return SDL_SetError("Could not retrieve OpenGL functions");
     }
 
@@ -178,22 +214,20 @@ WIN_GL_LoadLibrary(_THIS, const char *path)
     return 0;
 }
 
-void *
-WIN_GL_GetProcAddress(_THIS, const char *proc)
+void *WIN_GL_GetProcAddress(_THIS, const char *proc)
 {
     void *func;
 
     /* This is to pick up extensions */
     func = _this->gl_data->wglGetProcAddress(proc);
-    if (!func) {
+    if (func == NULL) {
         /* This is probably a normal GL function */
         func = GetProcAddress(_this->gl_config.dll_handle, proc);
     }
     return func;
 }
 
-void
-WIN_GL_UnloadLibrary(_THIS)
+void WIN_GL_UnloadLibrary(_THIS)
 {
     SDL_UnloadObject(_this->gl_config.dll_handle);
     _this->gl_config.dll_handle = NULL;
@@ -203,8 +237,7 @@ WIN_GL_UnloadLibrary(_THIS)
     _this->gl_data = NULL;
 }
 
-static void
-WIN_GL_SetupPixelFormat(_THIS, PIXELFORMATDESCRIPTOR * pfd)
+static void WIN_GL_SetupPixelFormat(_THIS, PIXELFORMATDESCRIPTOR *pfd)
 {
     SDL_zerop(pfd);
     pfd->nSize = sizeof(*pfd);
@@ -242,8 +275,7 @@ WIN_GL_SetupPixelFormat(_THIS, PIXELFORMATDESCRIPTOR * pfd)
 /* Choose the closest pixel format that meets or exceeds the target.
    FIXME: Should we weight any particular attribute over any other?
 */
-static int
-WIN_GL_ChoosePixelFormat(HDC hdc, PIXELFORMATDESCRIPTOR * target)
+static int WIN_GL_ChoosePixelFormat(_THIS, HDC hdc, PIXELFORMATDESCRIPTOR *target)
 {
     PIXELFORMATDESCRIPTOR pfd;
     int count, index, best = 0;
@@ -340,19 +372,20 @@ WIN_GL_ChoosePixelFormat(HDC hdc, PIXELFORMATDESCRIPTOR * target)
     return best;
 }
 
-static SDL_bool
-HasExtension(const char *extension, const char *extensions)
+static SDL_bool HasExtension(const char *extension, const char *extensions)
 {
     const char *start;
     const char *where, *terminator;
 
     /* Extension names should not have spaces. */
     where = SDL_strchr(extension, ' ');
-    if (where || *extension == '\0')
+    if (where || *extension == '\0') {
         return SDL_FALSE;
+    }
 
-    if (!extensions)
+    if (extensions == NULL) {
         return SDL_FALSE;
+    }
 
     /* It takes a bit of care to be fool-proof about parsing the
      * OpenGL extensions string. Don't be fooled by sub-strings,
@@ -362,23 +395,27 @@ HasExtension(const char *extension, const char *extensions)
 
     for (;;) {
         where = SDL_strstr(start, extension);
-        if (!where)
+        if (where == NULL) {
             break;
+        }
 
         terminator = where + SDL_strlen(extension);
-        if (where == start || *(where - 1) == ' ')
-            if (*terminator == ' ' || *terminator == '\0')
+        if (where == start || *(where - 1) == ' ') {
+            if (*terminator == ' ' || *terminator == '\0') {
                 return SDL_TRUE;
+            }
+        }
 
         start = terminator;
     }
     return SDL_FALSE;
 }
 
-void
-WIN_GL_InitExtensions(_THIS)
+void WIN_GL_InitExtensions(_THIS)
 {
-    const char *(WINAPI * wglGetExtensionsStringARB) (HDC) = 0;
+    /* *INDENT-OFF* */ /* clang-format off */
+    const char *(WINAPI * wglGetExtensionsStringARB)(HDC) = 0;
+    /* *INDENT-ON* */ /* clang-format on */
     const char *extensions;
     HWND hwnd;
     HDC hdc;
@@ -391,7 +428,7 @@ WIN_GL_InitExtensions(_THIS)
 
     hwnd =
         CreateWindow(SDL_Appname, SDL_Appname, (WS_POPUP | WS_DISABLED), 0, 0,
-        10, 10, NULL, NULL, SDL_Instance, NULL);
+                     10, 10, NULL, NULL, SDL_Instance, NULL);
     if (!hwnd) {
         return;
     }
@@ -409,8 +446,10 @@ WIN_GL_InitExtensions(_THIS)
     }
     _this->gl_data->wglMakeCurrent(hdc, hglrc);
 
-    wglGetExtensionsStringARB = (const char *(WINAPI *) (HDC))
+    /* *INDENT-OFF* */ /* clang-format off */
+    wglGetExtensionsStringARB = (const char *(WINAPI *)(HDC))
         _this->gl_data->wglGetProcAddress("wglGetExtensionsStringARB");
+    /* *INDENT-ON* */ /* clang-format on */
     if (wglGetExtensionsStringARB) {
         extensions = wglGetExtensionsStringARB(hdc);
     } else {
@@ -420,14 +459,14 @@ WIN_GL_InitExtensions(_THIS)
     /* Check for WGL_ARB_pixel_format */
     _this->gl_data->HAS_WGL_ARB_pixel_format = SDL_FALSE;
     if (HasExtension("WGL_ARB_pixel_format", extensions)) {
-        _this->gl_data->wglChoosePixelFormatARB = (BOOL(WINAPI *)
-                                                   (HDC, const int *,
-                                                    const FLOAT *, UINT,
-                                                    int *, UINT *))
+        /* *INDENT-OFF* */ /* clang-format off */
+        _this->gl_data->wglChoosePixelFormatARB =
+            (BOOL (WINAPI *)(HDC, const int *, const FLOAT *, UINT, int *, UINT *))
             WIN_GL_GetProcAddress(_this, "wglChoosePixelFormatARB");
         _this->gl_data->wglGetPixelFormatAttribivARB =
-            (BOOL(WINAPI *) (HDC, int, int, UINT, const int *, int *))
+            (BOOL (WINAPI *)(HDC, int, int, UINT, const int *, int *))
             WIN_GL_GetProcAddress(_this, "wglGetPixelFormatAttribivARB");
+        /* *INDENT-ON* */ /* clang-format on */
 
         if ((_this->gl_data->wglChoosePixelFormatARB != NULL) &&
             (_this->gl_data->wglGetPixelFormatAttribivARB != NULL)) {
@@ -454,8 +493,7 @@ WIN_GL_InitExtensions(_THIS)
     if (HasExtension("WGL_EXT_create_context_es2_profile", extensions)) {
         SDL_GL_DeduceMaxSupportedESProfile(
             &_this->gl_data->es_profile_max_supported_version.major,
-            &_this->gl_data->es_profile_max_supported_version.minor
-        );
+            &_this->gl_data->es_profile_max_supported_version.minor);
     }
 
     /* Check for WGL_ARB_context_flush_control */
@@ -480,8 +518,7 @@ WIN_GL_InitExtensions(_THIS)
     WIN_PumpEvents(_this);
 }
 
-static int
-WIN_GL_ChoosePixelFormatARB(_THIS, int *iAttribs, float *fAttribs)
+static int WIN_GL_ChoosePixelFormatARB(_THIS, int *iAttribs, float *fAttribs)
 {
     HWND hwnd;
     HDC hdc;
@@ -522,10 +559,9 @@ WIN_GL_ChoosePixelFormatARB(_THIS, int *iAttribs, float *fAttribs)
 }
 
 /* actual work of WIN_GL_SetupWindow() happens here. */
-static int
-WIN_GL_SetupWindowInternal(_THIS, SDL_Window * window)
+static int WIN_GL_SetupWindowInternal(_THIS, SDL_Window *window)
 {
-    HDC hdc = ((SDL_WindowData *) window->driverdata)->hdc;
+    HDC hdc = ((SDL_WindowData *)window->driverdata)->hdc;
     PIXELFORMATDESCRIPTOR pfd;
     int pixel_format = 0;
     int iAttribs[64];
@@ -598,6 +634,10 @@ WIN_GL_SetupWindowInternal(_THIS, SDL_Window * window)
         *iAttr++ = _this->gl_config.multisamplesamples;
     }
 
+    if (_this->gl_config.floatbuffers) {
+        *iAttr++ = WGL_TYPE_RGBA_FLOAT_ARB;
+    }
+
     if (_this->gl_config.framebuffer_srgb_capable) {
         *iAttr++ = WGL_FRAMEBUFFER_SRGB_CAPABLE_ARB;
         *iAttr++ = _this->gl_config.framebuffer_srgb_capable;
@@ -621,13 +661,13 @@ WIN_GL_SetupWindowInternal(_THIS, SDL_Window * window)
     pixel_format = WIN_GL_ChoosePixelFormatARB(_this, iAttribs, fAttribs);
 
     /* App said "don't care about accel" and FULL accel failed. Try NO. */
-    if ( ( !pixel_format ) && ( _this->gl_config.accelerated < 0 ) ) {
+    if ((!pixel_format) && (_this->gl_config.accelerated < 0)) {
         *iAccelAttr = WGL_NO_ACCELERATION_ARB;
         pixel_format = WIN_GL_ChoosePixelFormatARB(_this, iAttribs, fAttribs);
-        *iAccelAttr = WGL_FULL_ACCELERATION_ARB;  /* if we try again. */
+        *iAccelAttr = WGL_FULL_ACCELERATION_ARB; /* if we try again. */
     }
     if (!pixel_format) {
-        pixel_format = WIN_GL_ChoosePixelFormat(hdc, &pfd);
+        pixel_format = WIN_GL_ChoosePixelFormat(_this, hdc, &pfd);
     }
     if (!pixel_format) {
         return SDL_SetError("No matching GL pixel format available");
@@ -638,8 +678,7 @@ WIN_GL_SetupWindowInternal(_THIS, SDL_Window * window)
     return 0;
 }
 
-int
-WIN_GL_SetupWindow(_THIS, SDL_Window * window)
+int WIN_GL_SetupWindow(_THIS, SDL_Window *window)
 {
     /* The current context is lost in here; save it and reset it. */
     SDL_Window *current_win = SDL_GL_GetCurrentWindow();
@@ -649,27 +688,21 @@ WIN_GL_SetupWindow(_THIS, SDL_Window * window)
     return retval;
 }
 
-SDL_bool
-WIN_GL_UseEGL(_THIS)
+SDL_bool WIN_GL_UseEGL(_THIS)
 {
     SDL_assert(_this->gl_data != NULL);
     SDL_assert(_this->gl_config.profile_mask == SDL_GL_CONTEXT_PROFILE_ES);
 
-    return (SDL_GetHintBoolean(SDL_HINT_OPENGL_ES_DRIVER, SDL_FALSE)
-            || _this->gl_config.major_version == 1 /* No WGL extension for OpenGL ES 1.x profiles. */
-            || _this->gl_config.major_version > _this->gl_data->es_profile_max_supported_version.major
-            || (_this->gl_config.major_version == _this->gl_data->es_profile_max_supported_version.major
-                && _this->gl_config.minor_version > _this->gl_data->es_profile_max_supported_version.minor));
+    return SDL_GetHintBoolean(SDL_HINT_OPENGL_ES_DRIVER, SDL_FALSE) || _this->gl_config.major_version == 1 || _this->gl_config.major_version > _this->gl_data->es_profile_max_supported_version.major || (_this->gl_config.major_version == _this->gl_data->es_profile_max_supported_version.major && _this->gl_config.minor_version > _this->gl_data->es_profile_max_supported_version.minor); /* No WGL extension for OpenGL ES 1.x profiles. */
 }
 
-SDL_GLContext
-WIN_GL_CreateContext(_THIS, SDL_Window * window)
+SDL_GLContext WIN_GL_CreateContext(_THIS, SDL_Window *window)
 {
-    HDC hdc = ((SDL_WindowData *) window->driverdata)->hdc;
+    HDC hdc = ((SDL_WindowData *)window->driverdata)->hdc;
     HGLRC context, share_context;
 
     if (_this->gl_config.profile_mask == SDL_GL_CONTEXT_PROFILE_ES && WIN_GL_UseEGL(_this)) {
-#if SDL_VIDEO_OPENGL_EGL        
+#if SDL_VIDEO_OPENGL_EGL
         /* Switch to EGL based functions */
         WIN_GL_UnloadLibrary(_this);
         _this->GL_LoadLibrary = WIN_GLES_LoadLibrary;
@@ -681,11 +714,11 @@ WIN_GL_CreateContext(_THIS, SDL_Window * window)
         _this->GL_GetSwapInterval = WIN_GLES_GetSwapInterval;
         _this->GL_SwapWindow = WIN_GLES_SwapWindow;
         _this->GL_DeleteContext = WIN_GLES_DeleteContext;
-        
+
         if (WIN_GLES_LoadLibrary(_this, NULL) != 0) {
             return NULL;
         }
-        
+
         return WIN_GLES_CreateContext(_this, window);
 #else
         SDL_SetError("SDL not configured with EGL support");
@@ -704,7 +737,7 @@ WIN_GL_CreateContext(_THIS, SDL_Window * window)
         _this->gl_config.flags == 0) {
         /* Create legacy context */
         context = _this->gl_data->wglCreateContext(hdc);
-        if( share_context != 0 ) {
+        if (share_context != 0) {
             _this->gl_data->wglShareLists(share_context, context);
         }
     } else {
@@ -722,13 +755,12 @@ WIN_GL_CreateContext(_THIS, SDL_Window * window)
         }
 
         wglCreateContextAttribsARB =
-            (PFNWGLCREATECONTEXTATTRIBSARBPROC) _this->gl_data->
-            wglGetProcAddress("wglCreateContextAttribsARB");
+            (PFNWGLCREATECONTEXTATTRIBSARBPROC)_this->gl_data->wglGetProcAddress("wglCreateContextAttribsARB");
         if (!wglCreateContextAttribsARB) {
             SDL_SetError("GL 3.x is not supported");
             context = temp_context;
         } else {
-            int attribs[15];  /* max 14 attributes plus terminator */
+            int attribs[15]; /* max 14 attributes plus terminator */
             int iattr = 0;
 
             attribs[iattr++] = WGL_CONTEXT_MAJOR_VERSION_ARB;
@@ -748,24 +780,20 @@ WIN_GL_CreateContext(_THIS, SDL_Window * window)
                 attribs[iattr++] = _this->gl_config.flags;
             }
 
-            /* only set if wgl extension is available */
-            if (_this->gl_data->HAS_WGL_ARB_context_flush_control) {
+            /* only set if wgl extension is available and not the default setting */
+            if ((_this->gl_data->HAS_WGL_ARB_context_flush_control) && (_this->gl_config.release_behavior == 0)) {
                 attribs[iattr++] = WGL_CONTEXT_RELEASE_BEHAVIOR_ARB;
-                attribs[iattr++] = _this->gl_config.release_behavior ?
-                                    WGL_CONTEXT_RELEASE_BEHAVIOR_FLUSH_ARB :
-                                    WGL_CONTEXT_RELEASE_BEHAVIOR_NONE_ARB;
+                attribs[iattr++] = _this->gl_config.release_behavior ? WGL_CONTEXT_RELEASE_BEHAVIOR_FLUSH_ARB : WGL_CONTEXT_RELEASE_BEHAVIOR_NONE_ARB;
             }
 
-            /* only set if wgl extension is available */
-            if (_this->gl_data->HAS_WGL_ARB_create_context_robustness) {
+            /* only set if wgl extension is available and not the default setting */
+            if ((_this->gl_data->HAS_WGL_ARB_create_context_robustness) && (_this->gl_config.reset_notification != 0)) {
                 attribs[iattr++] = WGL_CONTEXT_RESET_NOTIFICATION_STRATEGY_ARB;
-                attribs[iattr++] = _this->gl_config.reset_notification ?
-                                    WGL_LOSE_CONTEXT_ON_RESET_ARB :
-                                    WGL_NO_RESET_NOTIFICATION_ARB;
+                attribs[iattr++] = _this->gl_config.reset_notification ? WGL_LOSE_CONTEXT_ON_RESET_ARB : WGL_NO_RESET_NOTIFICATION_ARB;
             }
 
-            /* only set if wgl extension is available */
-            if (_this->gl_data->HAS_WGL_ARB_create_context_no_error) {
+            /* only set if wgl extension is available and not the default setting */
+            if ((_this->gl_data->HAS_WGL_ARB_create_context_no_error) && (_this->gl_config.no_error != 0)) {
                 attribs[iattr++] = WGL_CONTEXT_OPENGL_NO_ERROR_ARB;
                 attribs[iattr++] = _this->gl_config.no_error;
             }
@@ -792,8 +820,7 @@ WIN_GL_CreateContext(_THIS, SDL_Window * window)
     return context;
 }
 
-int
-WIN_GL_MakeCurrent(_THIS, SDL_Window * window, SDL_GLContext context)
+int WIN_GL_MakeCurrent(_THIS, SDL_Window *window, SDL_GLContext context)
 {
     HDC hdc;
 
@@ -802,29 +829,28 @@ WIN_GL_MakeCurrent(_THIS, SDL_Window * window, SDL_GLContext context)
     }
 
     /* sanity check that higher level handled this. */
-    SDL_assert(window || (!window && !context));
+    SDL_assert(window || (window == NULL && !context));
 
     /* Some Windows drivers freak out if hdc is NULL, even when context is
        NULL, against spec. Since hdc is _supposed_ to be ignored if context
        is NULL, we either use the current GL window, or do nothing if we
        already have no current context. */
-    if (!window) {
+    if (window == NULL) {
         window = SDL_GL_GetCurrentWindow();
-        if (!window) {
+        if (window == NULL) {
             SDL_assert(SDL_GL_GetCurrentContext() == NULL);
-            return 0;  /* already done. */
+            return 0; /* already done. */
         }
     }
 
-    hdc = ((SDL_WindowData *) window->driverdata)->hdc;
-    if (!_this->gl_data->wglMakeCurrent(hdc, (HGLRC) context)) {
+    hdc = ((SDL_WindowData *)window->driverdata)->hdc;
+    if (!_this->gl_data->wglMakeCurrent(hdc, (HGLRC)context)) {
         return WIN_SetError("wglMakeCurrent()");
     }
     return 0;
 }
 
-int
-WIN_GL_SetSwapInterval(_THIS, int interval)
+int WIN_GL_SetSwapInterval(_THIS, int interval)
 {
     if ((interval < 0) && (!_this->gl_data->HAS_WGL_EXT_swap_control_tear)) {
         return SDL_SetError("Negative swap interval unsupported in this GL");
@@ -838,8 +864,7 @@ WIN_GL_SetSwapInterval(_THIS, int interval)
     return 0;
 }
 
-int
-WIN_GL_GetSwapInterval(_THIS)
+int WIN_GL_GetSwapInterval(_THIS)
 {
     int retval = 0;
     if (_this->gl_data->wglGetSwapIntervalEXT) {
@@ -848,10 +873,9 @@ WIN_GL_GetSwapInterval(_THIS)
     return retval;
 }
 
-int
-WIN_GL_SwapWindow(_THIS, SDL_Window * window)
+int WIN_GL_SwapWindow(_THIS, SDL_Window *window)
 {
-    HDC hdc = ((SDL_WindowData *) window->driverdata)->hdc;
+    HDC hdc = ((SDL_WindowData *)window->driverdata)->hdc;
 
     if (!SwapBuffers(hdc)) {
         return WIN_SetError("SwapBuffers()");
@@ -859,21 +883,18 @@ WIN_GL_SwapWindow(_THIS, SDL_Window * window)
     return 0;
 }
 
-void
-WIN_GL_DeleteContext(_THIS, SDL_GLContext context)
+void WIN_GL_DeleteContext(_THIS, SDL_GLContext context)
 {
     if (!_this->gl_data) {
         return;
     }
-    _this->gl_data->wglDeleteContext((HGLRC) context);
+    _this->gl_data->wglDeleteContext((HGLRC)context);
 }
 
-
-SDL_bool
-WIN_GL_SetPixelFormatFrom(_THIS, SDL_Window * fromWindow, SDL_Window * toWindow)
+SDL_bool WIN_GL_SetPixelFormatFrom(_THIS, SDL_Window *fromWindow, SDL_Window *toWindow)
 {
-    HDC hfromdc = ((SDL_WindowData *) fromWindow->driverdata)->hdc;
-    HDC htodc = ((SDL_WindowData *) toWindow->driverdata)->hdc;
+    HDC hfromdc = ((SDL_WindowData *)fromWindow->driverdata)->hdc;
+    HDC htodc = ((SDL_WindowData *)toWindow->driverdata)->hdc;
     BOOL result;
 
     /* get the pixel format of the fromWindow */
